#In the name of GOD
#----------------------------------------------------------------------
# This file was generated by img2py.py
#----------------------------------------------------------------------

from wx.lib.embeddedimage import PyEmbeddedImage

accept_button = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAmpJREFUeNqkU01oE1EQ/t52E5PNj01BSqlWyLXeWgvGggpF'
    b'RAo96c2TImgRKc1B8OLBQ9GmIFVPemlBwYKgFKRQFLyI+bGaUtHYWCzW1ND8NnbT7J/zdpNN'
    b'td4cmH3wZr5vvp2ZxwzDwP+YyD+MMfvi9Dh6VA1juo4BTs0jggC0CJgnvzY7ikQjlxdn5qdO'
    b'cOoW7gW8/svnjl1E98FDUJQKivI6fhZXkVx5j9jyEmqKNjMbxtldBAR+0tnWcebu+Wkk16bw'
    b'4dsUVJ2ro+rkLkcQFdmHV8lFyDX9PikZtgkGI6zH55Lidy5M4+WnYeQr66ZsUxdryLW8UGxD'
    b'LJWHZqD3+YiREHhQUXF78PAQFn88QI4kC9QZ1mI5KEOlQ9aASyEDDlce7QFA1zAOK2zaiWD7'
    b'ASznXpiya+RUAXRApbNKDCP91rRcEuD3mMqO21PgoapWxjYhroasxMgbBgfR16hyuL85atFh'
    b'TgSN6QvWGIHyr6wluW6jRwxsUuVwqAmeeMsginZbmgQC3eTKGTiJPRJvhq8fbYIjMQb3HgIT'
    b'QtMZGqtjEmjbiH7JpKFXW+FxUfI79se2RRIW2OEESgWGzS3qTRVRuwcbHzH22Zd96nHvxb4u'
    b'wEskk0kGvb4HEgfT72kKkM0CmYKBLGFsBQuPMVfewMxCuoSVlIBKHnBTNS9120Ndd1KZUo7h'
    b'a4ohnTFQ4bmPMGf2b8cqd528gYdSKwY6Agw+ydpA8xepFVw2r8zB8zcRpuvVXW+BLNg9hND+'
    b'XlwR3ehrjIqHVRnR73FMLj3Daw7+52OqG9VGJ7n/r5dbJl8j39r5Gn8LMAAV2Qj37wA9/gAA'
    b'AABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

add = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAlxJREFUeNqkU0toU1EQPfc2bZKHSRpLaUu0YMGNXbYVEfxh'
    b'EZFCV3UnCIqCRUTsIgsXLlyEWhdaFRcKSnZ2pRTclC7EhYa0kErFQrQgjQn5NE3S5vs+nXn5'
    b'FVNw4YV53Hfnzjkzc+YKwzDwP8vCHyFE4+DSDIZUDT5dxyhDs0dKoE1igcw7fw9L9btMLsxP'
    b'DeDiNJ67DzhvXTlzA8f6B1FWc9jKR5HIbCC0HkIwvIpyRZubn8LlFgAKfuc52Dfx7JofK5G3'
    b'WF73o6RydoCV8lQ6BrBTdGExtIJCWXtBmUw2AMYeiyGHTQk+ue7H4o9JpLZjUHXgzqlqf55+'
    b'FrARiBTtSKa78HUtBk3H8Ie7xpLkCxUVj8ZGxvHtzyukCjEqGNCbbYHGRv9GWwV2ZRO9bvJr'
    b'mGGfrN05d6TnMMLJjyZzmSJKehOA90Uqh0uyK2U4FbO7ZxsqcKIlbYvq7MTNkXSLVN7TTalf'
    b'LgtTlbr6siojkNlJQFjkv4WX+8yBJIBUNgrVsYlZYuAyOF3viSqN74swlWin3lgJgGYE9dEx'
    b'8bQSAuHoLxhFN2xWqpPM2tFk4T2fsS+bAXJ5Iiki0ABIfodvLRJHMqHD0CUszGZpAvCezzTK'
    b'Kh4XiKYNxCnGLL82SMr5+3jj6sbEUY9Ed48ORxfgsvWaAJliDLkUBccEfkYNZOKYW3iIqxSb'
    b'3zvK/Rce4LXSidE+t4DDbjTq5I7nClXm7aQZPEXHv1veAq2BwXGcPDSM2xY7jtelYrdaQGAj'
    b'iNnV9/jEwfs+ptriMfGQOf8SMEsWIcvvfY27AgwA3EwHS5LUr7EAAAAASUVORK5CYII=')

#------------------------------------------------------------------------------------------------

application_add = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAepJREFUeNqUkjFIW1EUhv9z733mvac2aOJQ0hrUQlEIgpam'
    b'dhCHIp1cipisFbp0aWvADjqpdGjExU0hq5B2cbQuQkNBsYOCWUTFwQyCiGI6xPdez30aothG'
    b'vXCG+975/vtz/kOPppZyJcd96Xke7nqICIYUC1JQUml4cuA5HNeFuAPsckkhMLa4mhAkk+qc'
    b'wZCpkFrah2IFqgJrj+eskO5vhuZq+EkW8NBgGngaroMkba+KACs4XLpfc/quSqzYFzW5orjP'
    b'0Zw+yr0cXj6/xRZvt0Dc1d7eAc1pUpX/1dp18P4Dk/9d+POpdEgWkBUB27Z4wjcFiEEhFMdm'
    b'QZEBUW6hIM+hBqocv2mZbOsmLoUBywhg/tdbLG5m/Kg5NHSFB9EZyl5xYFm8C9cVOGdIzjbz'
    b'8x3WCxkM9AI9kRGsFaaR387i6BizomxJSLZpGNdKw/p8+z2HWCtwVgRioTROzoAnj/0k3gte'
    b'yVsjCxhAnF/++OLC4Ye4h2cPR/09oPrUwgrZD3p5pf8xAz3pRiTb4oi1AcUSMP7Kw8QywWbR'
    b'jR2O8TSdGObOYDUHxRk5uXvgvI6EgdzeZ548sHMA/DnCd4p++VFl9yVKThCFse6WoWl8DTTg'
    b'jW+bLuBsCp/oHtvbzNV05X7Itf9XgAEAdUyeqmc4PvoAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

application_delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAeZJREFUeNqUkr9rU1EUx7/n3vte3ksaRK2L2AQXSxxcChIE'
    b'oUXRDhIUJ/8GB0EyCoK0OOhQRAXp1kUUsohSaRYdXAQpCLUuClYQ8UehgdLWJvf6PabVFtO0'
    b'vXCGl3s+3/vN+R45NDr1arXlT4QQsNMjIoiseWGNDDmFRyrH0fIeZgewZ1ljcO3J60EjFq5J'
    b'cH/iUJ2ag6OCdIHVY5MKt88UoFzMJykQsDeJ0N/bAytqr4sAFVos7VdOv90qFQeLCauI3Rzl'
    b'9Di/NrzZ2Xe0uL0FYVepdBTKKenW73LZHoQtYJ26CisuaD8dxMCz/gpksymvpBMNsQ4SxUAU'
    b'wZh2z0omhwZ/c+vxJ2lCWx14R4h3X8Zu4OfDcRhrkWFa1dIFXPk8ucFBmnIXNisI81bg051R'
    b'4OUzlCsVuqAT38S+mbeYd7m7bs0RGx2r8+y+TtxDeegkwsIPBOYvFO3rO4hv8wuXHVdy28ji'
    b'OIKcOg8MX/o3pfpj+OkZuNQvvdlzfXKAK/3fDAL/wq9MHu+TGKH2AM1H9+HZZ/io6EDpRAWP'
    b'sPLdHDw9OzDSn5rhQt7+2QON8+Mi8KGxXJPizfqWYIs5NxzjqpYPPz997FZvml5s7wLnsrxS'
    b'O1efviq72N4C68CG7++sud8CDACp8J9A4CbcpgAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

application_edit = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAkFJREFUeNqUUk1oE0EYfTM7k+xuk2qIF0trtIriQZQatfZg'
    b'KkJFjDkpHsSCCIIXqdBT6dGgYPFisQe1GiFFRQRTT/GgEStiLXhKL4o/VK1SamqNtWyy4zcl'
    b'0VqTUgfeMszOe9/7vnmsPp4ecopui1IKS12MMcwU3MGAJWNCk8/EtqPouuBLILsEg3N0p54f'
    b'0DVFgYhBU6Az/R6CFNgiZO2xQAo9baugeR4qSQIKAVNiwwofDKbtLSJACkVCwPLA0Xs6Ew4p'
    b'toZMQgj/s75pN+RXuKXhjY5myWJlC+UTRr0bHgPOtdd4Y0m40zmI8qUa2wdVxb+eOucGhBS4'
    b'm7qHfVv2YPzTBKz8tPotYNsWTbiCAOPghqTKFpLJAcSiUSQGrmPbZBNk7jN4+flNy4Rpev+G'
    b'ZcH2+WEH/Mh2r8GRiI2rN26huWkHHvI0wn0nw8zbdV/9jO+HWyxQFtSfnqlfZhgwaJs5vRaR'
    b'Qw3A2DtkjXb0D/3AxWAUXqloLCXX3BCQUs5BaJTIjzoaibwa+DgB5HJ4kkqg58J5SGcWfirK'
    b'pVE9f5lTDWg9WA98GAemviAxXIcTibdz/wR0cund/J03M8yu3UWRhu5AD9JRJp6uv4OdbZSN'
    b'yRngWS+SL0M4WncFpvMVHuXAzeceB4LBiG5gHWHZwuq344df1DZuxN7Ny9Hfm8TxS8PhBVem'
    b'QmcfvGL0mZd1hlnuRdfYOeRUjRLOd+xuDqHlWF94sGPTSPvKy/C5ebLu/hOySmvrvP1ItUu/'
    b'BBgASa3Cu6z82mEAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

application_form = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAa9JREFUeNqck7tKA0EUhv+5bGIheCkEiWgKu0SNNoJgYoiC'
    b'MQn4NKltbHwaURAREzWFICgoWPgCFlHxUtiYZNZzZjYma1TU2Z1lmZnvP3P+MyPGNg92Gi1T'
    b'avk+AO6/aQJKCHhK7uo3grfW50EifxIgGOXtsxILID7ch63TWx7n98fmB5/yQgzM6iYFzowa'
    b'ZEoj6MHFdwrUIgbMamMHBS6ubwiQXSw9slfBZ6+MwdxsAszq9oQX6SNAO4gW8bqry3ML+MaF'
    b'dYICqZnZD8GOgPZwWDmEkhKGoNzyCmLjcWTTi6EdVE9qkEp2CQTVU1piNZ+3UTiioW2mksme'
    b'FFJTU7i/q6PNaT9whiP7wmYOSFfnx+dnPDw92ZRcDnYWmnbLjB9OgX6lgmShAKhWKx3jLO9M'
    b'zWWzX3jgRbC3v28XMbCWL2BsIo7cUiaUQuXomILoTwIECKVQKBbJAxk4bzCdSPR4ME2+tJqN'
    b'j7S0cJVBVCvYaongBCkWMriv10MpcI962p1a6trj2hI81B/9dBV+uBfCMcxq8/pSG9w4Tjc4'
    b'/O/vkoWZ5Q1PUh/A/9rLuwADAK8loV8tdNaPAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

application_lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAjFJREFUeNqUU0toE1EUPe/Nm2RmOq0dPwVpbBYqoosEWlAQ'
    b'seIi1EqL4MKtC0Hdxy4kKoVCwe+uCi7dqAsLTVDRKPgFxY1GjQ1KtGqLxKY1jQlxJvO8E1uF'
    b'2Nb64Czm3rnnnnfufazp+PURXfAeKSWWehhjKDtu3NLVXuEVD/RuRtV1wZdQ7BIUzhEbedrj'
    b'9RQOFa7QBKK3xiCIgS1S7Gl0iOF0pA22KyF+EUhYmooNK00ozJM3r+gaPIIqETTrGsquAkdq'
    b'EDYFdgQ1QhD/c8quiclADMKdNS+dfk0d/pbAmIAsTkA86KO8qOVVRcEnavrVNaWY+7HBMCHr'
    b'9dM3U/xw8s9JN0dr114KcjJRIDucwON0LvabwDB0criegIMJDTOF99BaAvAt70YpE8X0mIOP'
    b'toX9Z2+cF3Pj18gYt34ViID7DExNjsIMtePHxCU4FQOFDzkMFLsxOjSe/6NA18lhWVevgK6L'
    b'79mHaIisR7U0jUpRRaVs44J5kRoKKfisaq4IwgLzd8t4F0/Ab1lYszWElvBa5B6lkHnxOclV'
    b'5d/7134si1Whw2huC4BzH8aHk+h/Gca2o08Ossbo5XvMaNpu04bUe+CN1YZa2/3UxnPYtKcL'
    b'r64k0P9lF27mV9+HFez0LrCOsGwxBUMndp+JBKY6vYfQd8c4dO1q8hmFv7UO3n3LgoO3F3g0'
    b'HEXoeOPfh7xslCVXKXQcSe2kVObAqZMzcWcL/KRvqaeDEJ4v8VOAAQAI1MRifLBK3QAAAABJ'
    b'RU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

application_put = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAixJREFUeNqUUktoE1EUPe8z895MY2tqkApqta0pguAP3ChV'
    b'gi0oVEHduLAbN7W7oCCiqKggiL+l6E6sgqCL6MpYIeJCXUsKXQTbhYKhNVajtJPMeN8kk3Qh'
    b'tn1wuO93zv0y5/zLTKuSg0EQYDmLMYbZucoLacjXDu1C1ffBl0j2CYJzXMh8HJQVIq7SEmde'
    b'TUGSAluEbOKskMLNgfUwXBIIENcWehMxCGZCW0SAFKoEwzFc6ZHavk5N6MRyl+FKv1688fE8'
    b'hcfC4tTLRBFJWFJDMkX3nLz75HUOXvU3kr2bYLgyUnO0g4A1y8hpr2QMd3PHMDbxJkzN+Eol'
    b'U0j3PW38awjoUIDVfZN3bqFFxUPyveND+PXnK2LOGgw/eYjLB9sb/ySCSMCm9rDapbDhWC4o'
    b'+rAzpflJFKZz6Fq9Nzw7bTVHQlB60fhopcPqcibg2ApbLzG4NsLOzHqTYHbNCvq7+yoDdR6u'
    b'lW3OjtYKStlQZE1iqW3A/eE0Th4AZrzPgFWz5vzg1Gns3w608jw4j4rOBaSUdFE7fism8Oj9'
    b'HXR3HIFP3iN0dxzF6IdbKBbX4ae/GdwS/x7g0ZEiNron8Dr/HGsTO6Bci+xOjOWfoTy9AbeH'
    b'pqilNphOP87ZK1b2eVWf+tpsoRCKbBw91lkc3pPFlmQ7Pk3MIPNuAIXqDcq9hHLpy1uTQA+h'
    b'7X8T138R12UL+itlZLNXcG7B0w+2xKntIsQJ3wmFhQ9/BRgAwTqsFR2Vlj8AAAAASUVORK5C'
    b'YII=')

#-----------------------------------------------------------------------------------------------------

application_get = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAiNJREFUeNqUUk1IVFEYPfe+O/PuPCefk0GLIFtMuW1VtOiP'
    b'UILQInARRUUbC4oWRQsJJ6MGAmE2QrgJN61qo2KKjVazCBJJIlCmRUTkokULsVKb99O5b3xp'
    b'RakXDt+73HfOPfd8n3A7hwa0slrCMMRGlhACi54/qAz5Tuse+EEAuU5yQFhS4ubARIvySKzX'
    b'CtdHP0JRQaxBNj49KnQ3b4fhUiBERifQuCUNSxhrawhQwScMx3BVhWqHGjTRgI0uw1XBcngz'
    b'M9O0J6Jw/oiLzhJIKBtSKGblwfcXsLMxCxqAin9L6RRCIf9K2pJJaFWL7mfHMVouomnXEdw4'
    b'3L8sLVaC1xTQWv9CSjtIO7XIbNqKwos2+JUiRq4+Zh1DodQWcSTFJcJYIAnbjmHDcRy46Trc'
    b'e3oCS94TXGzqwfPpK7jU3IMf3jDuF89QIAMVj4+2dZRu1bpF2zZu9bdiwR/EuYMdGCtfjs5M'
    b'Pcv9o4k8ssnPKxlobUdtqVpTBDBP8ql9pzH5KQ+6jVpoMp6czePk3vNwdB9nJw5dWtEgrV7j'
    b'b4FX5YcRqXChHVOzvdi9rR3XHvSyK310SVrC+vcAv7kb4mWOw0KBefkOsqZaDWW8g2eLr/mE'
    b'73MlNzd8oOIHCMLfWyjZf8jN2J8Cluz3SLrV6vDmuq4phF/LJfOALOH+b+KOdqJL1OCYucA8'
    b'OfyGoZHbyPFoTqxzancQ9av2X4gP5uOnAAMA9ZixG4ZCuckAAAAASUVORK5CYII=')


#-----------------------------------------------------------------------------------------------------

brain_trainer = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAApZJREFUeNp0U1tIVFEUXefOmXGcUccZn4iPMbHyUWYiFlKp'
    b'CX0EQRBBUJg9fvwJguonP5KgD01Io5/6SMqPCCIhIqiPyqSHD9IMxTA1ynR8zNg0M97n6dzR'
    b'K+pMCzb33Mtea++z97qEMQYdhBAYuFlX1GSJtV1Kyd1mZRqDIAiYGvywTC0xLRfvDzfqOQYv'
    b'fDBebp0rddxuqJAG33WwFYRYUPwWfuoY6ulgLacKfq/nUayDJIn36q61m802O4Y6T2Dyy0C4'
    b'OtNUxBUfQfXJy4AqpbfStus8/arOEdYLOJLTjqVk5ON58wXMfv+KnGw7FBoHmyMezoUXeNZ8'
    b'Gjv21UAS5XqDs0EgweXCzFg3MmJnIasU0wsUKU4TP5vxadyGJG2cZ2lwFxZlRBWQY51t6Vuy'
    b'QJJ3wuxIg6bIPF+FhTIUZmuY8/F0zQemymucDTP40fu23jNShv3H60AoRU/XU0x9fo+sNAGB'
    b'gIy4rdVAyMsnqEUKtJ7d1bT3YGV8amoC5MB8eK2Vhw7ArPiwGKQoripBZm4WIHqx5PUi8goa'
    b'GneXF4CJfjDJD3X5D+S/iyivrYHAZPgXPNBCPqhL85jzeEcjBPonfA1PHnSByH4QLoLlpTBB'
    b'8c+jprYU+W4Xb9+HmYkJBETtZcQVOl9PPixxJ94Z7h5A4fZM3hHT3QIGAmZUowIX+AlrDBWj'
    b'DZGXFTw5LkuqEPRCCAvo82JQNLYiwk1lVSUIJlNi1C2Iitrz6NXo0QQbxdi0/5esME95nrP0'
    b'cEkS9wKDJhC4bSrMlFYYHLLpZ8rhkWzo6da4caas/8oeu50Y06IEd/tCON/+kUR0wDG1Gmuw'
    b'Etb7eCRUpa6u3sSF/EH1zf86iIY8Hombvvk4T/c1/gkwABOTKeN1Na44AAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAllJREFUeNqMU0toU1EQPfd9k4qF+mkg0lREUWqEWtQuWqOl'
    b'2rpQ3HXjTl0IdlHowrVLF4ILCy7EjTs3KgrSoLaJdVGVCDVEix9sJNXGxmhsk5f3u9556bPR'
    b'CHZguMzMOefN3HmX4S9L9HSMccc9zTkP+DnGmMFk6cahp5nz9ViBAfODZG90wLGs8bbD/Wjt'
    b'2getpQVelQNmsYh86gU+TT6CrKqDsal0/A+B5MHoAJPk8ejZcwgEdZSnk7CzH2Dn56G0hqFE'
    b'tqGpOwajUkX6+jVw1xmMPUnHfwtMdO/ke0dGIS/kUH54D65jgcky/Ba440CSVTQdOQEntAUv'
    b'r1xG3/QsIwEp0bN7LHL0GNRCHuX4bRoYshaApGjCVe+kmPJUJxzhiUcfl1zXPRPq7ILx+D5k'
    b'VyhWDbDKMlh5adVFTHmqE47wxCMBRUjrSj4Hs1rBhgcz+J8Vj3eC8MTzOoDEwLPvIUkK1mKE'
    b'IzzxagJiNvbjO+TgujUJEI7wxPNG4IyZtmVpyvpmLJ/qB2ybFtzIJIKigHACD+J5AoumfSdf'
    b'WhpqC20G03Tv58A/+LRRRhsSIp8XvoJ4K2lEJnqjc/v3dCAQ0Ol2ayINDTAxvwTDqOL5qwz6'
    b'ptLtApeVRC07WSgNpzKzMEX7qq5D1TSoqgpFOJ1eLPJUJxzhibeyRuDi6+xNOu3UzNXtW9sR'
    b'DofEZQXBeK1HxzAwn/uCdx/nkPj2c9jH+yP41ix8x60Duy5sUpWT4iI0cB/BzEXLvjv07M0l'
    b'EbwVXmp4jXUWEb7RW/GqucILftv1z/mXAAMAUKIIFQm47kwAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

edit_button = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6RTUzOTM3N0U3NkFC'
    b'MTFFMkJEMUFDRjAzNEZEMkMwRTYiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RTUzOTM3'
    b'N0Y3NkFCMTFFMkJEMUFDRjAzNEZEMkMwRTYiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpFNTM5Mzc3Qzc2QUIxMUUyQkQxQUNGMDM0RkQyQzBFNiIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpFNTM5Mzc3RDc2QUIxMUUyQkQxQUNGMDM0RkQy'
    b'QzBFNiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PpLMCisAAAG5SURBVHjanFO7SgNRED37yOZFqnSCYiH4AQpiKxiV'
    b'GDC2gn6HJiYGLNL4EVqJKBGDQop8gVgI1kFIYZVCQwzJPq4ze3fNTcDnwOzlLnNmzpmZq60c'
    b'N3b7Q/fUcT0IgR9N0wDT0BG3jL1mIXOG5dKd+I8FOJguVWZr9egjvqoonRk6LjATB0KcHmI8'
    b'uvM/T3EGEFsko8Dqfg0nV4/QdRkf4nQtTCAkwAucAwyqmowR+KCOVNxC46E1YhYmgMJgrDJF'
    b'JC1grVBHzDJgE71mNY+BPS7R5FQOJIjd10xpE1R5o1RHNGJgaLu4reTQ7cseOAoFk09bkUDx'
    b'iBN4s0yV6TIg8M1RDq8Eth0JsiclOJ7UzA2yTCB7eE2n7oNrZQlm6n6ThYyHmmDoSerRCHB3'
    b'38b64hz6hLgs5fD2Pg5mH7pKD7SAAc85X6lhKp1CdmkeF8UtH8ya1Q31JXsjCZ8JZA8EXjpd'
    b'ZBam0RvIqpPrrQfxmjoFzsi0zovb/s9+QFmoAw9McLxQpmBS53hhEtaoGsuB+O4x8ajlCpm9'
    b'9lN5p4oK7/YvHqNf2KD9Zhxtin9Pk8/i7/ZMPet8CDAApqgNk/2TrwAAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

information = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAp5JREFUeNpkU01IVFEU/t6972fG1JHGrLBso2WRSAshonIj'
    b'FrZQ27QoEQza6K6gXYS0KKhWuijIjbZw0xhRoEagUhRWUIJSWuL4A44OzDjhjOO89zrnzjwZ'
    b'68Jh5pzvO+d857x7NfxzSq+Fem3b7XBd1+eSr7FpWkpKrW99oLUzn0schauzr22o0dC04ca6'
    b'cpyrKUMw4CMGJwPr8RQmpiIYmVzGtuteWOtvGdlVgJP3B6zhW1dqEEvZeDcTxczKH2xuOQj4'
    b'JY4dLER99V6U+CQeDk5hNb6linABwQV06tzdfgqf5hN4Nr6EudUkuluqsPS4Hjap+L2WRN/E'
    b'ssKZx3xPuc4zd1ysxNivOL6E4yj060hnHAiRnc5nSewxpfrPuGkKMP+JE+qlUKdwHOd6+YEA'
    b'vi4kiGjAZ+jK7r2ex8k7H+E3dVjk8y/jzGM+52XVQ7PC8TT8hlBdaSxkSPf3u6dV17P3P8OU'
    b'WhYj33BcMJ/zGBe85XgqA8vSYRoSBhtJHpyMqAJCl9BzccaZx3wt9/1YAQVski1Ud2pAi3Oh'
    b'S7VfmLpQJnM7yTa0WYFXwE07tmNaNB/NlS1AoJdg5jp7vhACmQwpoDzlO6no0MpKDAW0bR+T'
    b'VUdtRyLPSLdQxRlnHvM5D7mbWlF69cVCU8MJFBVZ2KZP2FQdQHNtcOfKtg/MqmSDiiQSW3jz'
    b'dhrrzy8foYsU1gkPZxbfd42OyZ5LDcdRTEVG5xJ4NR1Tl4iao9hv0BgCG5Q8OvYDzOc8TwGf'
    b'4pLzN9vkoTM9dbWHcbSyDEUFJrzHlNhM4+dcBJPfFmEvfeiKjT/qp/DGrsfERciqgq1Pb2v+'
    b'YDMt0/QA2l/aTUZfRkM3HpA7y8n/vca8U0HGCxB5MYcs6snOf85/BRgAU2QTxLlxCL0AAAAA'
    b'SUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAk1JREFUeNqUU11IU2EYfr7zMzZHpbC1jChW3hRZMfuRCq+S'
    b'TLEbu+pSCsIgL6RdWNhl1E1EQWk/4GXdBBGxfggbyFaa1bQkmS5jbLNtba7trJ2/r+8sFzp1'
    b'0cM55z283/c8PN/7nEMopTBACEHw7tGDuq4OU00FFvog7OI4EF5klUddp4cY7RJPwCLk8vn2'
    b'ja5dsO07C12VAE0CJ66DWsgi9KAXT0di51CGJQIC0dvM9i2Q05+Qn70BcCZYt7mRePsYUkGZ'
    b'6u4fH6woIJpovdnmhJz6zCyvgVizn5lIIxMcRUvf2Am2JVMuwJVegneaXFW2mqImVcLMuhXi'
    b'2h1IjnkQmM1ejaUKE1gBfx1Iv5SOaocTVE4AegFEqELcN4Cf03Hs3mx2T9064DaGSHihONQ/'
    b'410kwM7fbnFsgK4lwQmWYm/94R44migoVBCaY5VDxNOPuWh2aGu5A1FEvdleCzX7DbzJChYn'
    b'lMQTI19wPF+MLeb7gFg097yxZ6SLdpcJEI4g+uIhc6CBqjI2He+DMu8FRxUokoT4aACTwR8D'
    b'xy4FrrDtM8tmUHfav9eo1045GzuanTcJOybPc1CyKqJeH7wT6d7O61+MGCOrxfjOeLS4qi+b'
    b'7XY2oQS0vIzI6yEMT85fZOTbbDlV8TsoNgQ0W2p3Qkl9RfjVM5y/F2p95Eu+WYm8TGDmfsNJ'
    b'qlFGDiPuf48Lg6E2Rn7JlhSsgiUCskq7TDwwF/B/337mYytrjVciLxMwCTik6TTDyEcWyP+G'
    b'kW/p12RoYPee/+H9FmAA+Yf39yJOQikAAAAASUVORK5CYII=')


#-----------------------------------------------------------------------------------------------------

separator = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6Q0ExQUNGRUY1OUI1'
    b'MTFFMjkzOTlFMzVFOURFNDVCMTgiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6Q0ExQUNG'
    b'RjA1OUI1MTFFMjkzOTlFMzVFOURFNDVCMTgiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpDQTFBQ0ZFRDU5QjUxMUUyOTM5OUUzNUU5REU0NUIxOCIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpDQTFBQ0ZFRTU5QjUxMUUyOTM5OUUzNUU5REU0'
    b'NUIxOCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PrqlUgUAAAAtSURBVHjaYvz//z8DJYCJgUIwagAVDGBpnLCIonhk'
    b'BGJjigwYTUjDwQCAAAMANs0I/5zY9nkAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

table_import = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAfhJREFUeNqkUz1MFEEUfjO7i3eQHGpnhZW5iCEk0NmYIIkS'
    b'giYUGi2vR3qFy0EQEwoSKiVQWiGGggvFXWFjZw+ViUZjjMHjctwhs7P7+GZm71ilkbDJy3z7'
    b'5v19b94TzEwX+fzrr6oWmDBhFG81VfQgjIliKETnRiTmDgv8BpKop8s78NuRYngY53rp/n9n'
    b'7y3uXO4EMLFVlND5OIpEASSmYm2NSlcLVl38vU6lKwWTjeh2hUIk9dvOGiWAgjWcP1glFpIk'
    b'Ss3KkBZqb6ze4HlgYzeXOPoaUWI0sqUi0ovjJKY26cfyJIxc4I3qHj25m7cBDH48krd3zp9J'
    b'7jcV77cUN1qKvh5DuTJJ155tUK4LTQKLADVe8pz4yZnxTvsgOPWOX1qu4X1ZHNPvaX3iFmnc'
    b'6oSaBCeDjUyP9VP2RZnou2L+Bvl8xPxLObFBpzYZ1Hi1usuHOI28ruxyA2ctcjaZ59vs35gr'
    b'2yc8Upp46aErC30wVOygQDJJhYFwWMsUBciQAbnZ8qd6acw6v3s0QH907IYJZZsEaQoRnrEw'
    b'ctNSEH2LFdvtYx2hmSGFL8f/Gpa3H/bo6Z38GWy+bgSQ7TJ+ztwb7g68M9OWdkhjS8mTroLO'
    b'LoS63tScM4PS2QWRXKaw3QU49/iiIf5JOAjxzrGMkbjoOp8IMAChbgwty8w4LQAAAABJRU5E'
    b'rkJggg==')

#-----------------------------------------------------------------------------------------------------

table_lightning = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAntJREFUeNqcU0tIVFEY/s65dx45vmYzMdjTRUSiSREtamPp'
    b'zCAU0cYekAWRm5bSQjQtXEatoiwQSpoiGoIeSjVaWU4JLcIeDlbKOOZkhTNM4+TMvXNP59x7'
    b'nR5ESD/8nI///v93vu/cc4i78158LpsrVTRAYwCBCA5M9CcmhMBCAYdVSsRavU4UH+9l/xNi'
    b'TlBSRWMG+dM6IFQPPPOhvXcKeO7V8zd8dxIYqtHbs5oxJsOcb5vtApUkyFyenSrojHfpdR0n'
    b'Lug2rBJDR6IbHYKASQYBMxn215aDcqsWXg8Ew9hbu1av3+gfwx7PGmic+Howhn1et17XWJGp'
    b'wAw7bxAEQoFMGWzUqEsSP7T4DFT/LjQQC7RRYJwrja62g3XvZHmCQPANJM4gSZRLpQj0hw3Z'
    b'FjuGBwewqYSizLeb66V8IxkTN+8gNPqlNU/Q6Kvgv4jvzi34H4RxwGtYuPIois2uJOQlyyA7'
    b'65Eea0ZqUkVUceLg6b5zdIFASNZT+CLGqmNKoXx6BceKDcjGeqBmCpCMZNCZqhdjs3kFV7kF'
    b'cUlkbsPGD8I/wC0QbsdWjPnxx3DUNEKdSyCTsiDzXcH5wovQzm5n+d942FOhr0LSpYdhHNpm'
    b'WLg8NA1VTeP9rduwlTqxfEslXFXl+Bx6jXcjH4OUmLeUmqljxhaEgarzqGz5gKJ1TShZWcZ7'
    b'LIgE7qN9pApbW4abFn2VJ67tYCx5hk33eBiLDTLriZC+C3Gf7EvOqaxIyWk/HxMx3pDGQZbY'
    b'ccTai+alT5BmBWj4ehRTzIVCkvk201ZXLFqrxX3BPyJyatWLuFYwW33sreeXco7nSywyNvJc'
    b'/7cPPwQYAOJyPDBxd4URAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

table_refresh = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAqBJREFUeNqUk1tIVFEUhr+zzxnH8TZjQSKBVNRDiiFoEYZJ'
    b'NIYlUZAvJthD0kP20OUpyvuUSGJCF0wsYeglJNLITDPELhamWYQEUVSYVGBp6jhNczntMzNp'
    b'V6jF2Zx19lnrX/9e+19KoqNrwvXVb/MGIKCDgmHSCXtzfvBRgrsmAVERYtKkinjNSP5cuZn/'
    b'NVtFly1W6Gheo6xhd3NAmGSZAOWTzVTGF8tNQeXEecoX7JGuhazOVtxeGKzWJS8zui4BCOeX'
    b'fjqHUNUgPYsIUDvlRBWRWM0aJ2evIBQNv6LQsvs02dXGeZ7ix4emhxEK7ctQ5b5Jg/beMTLT'
    b'vBxsTJAgMlYJdcKeCkPv9lGzs4yq1lSizEgGYYuUgUIGmlVwe57J5By2rIcliaFkyRafP7Se'
    b'u6s4kF/EqXanPgdwuWdEVlOxRFjpGM7BngXTHjh7ab5x2Wth+VJIiltDbYuT7sNkzAHsyk0J'
    b'MoiWDC72w+h7iAlksd/eyY7M6GBMZoVCenIU1U0DDPg/sL0+YUh8BzCLEP0vfh2PpNlcoNNQ'
    b'eJsT3TFkVYU0YfSj/sIsvaU6iVod49PoSuSRa7rbkUdT94hkIIgwWYg2x2NSrTg6FNpKzpDf'
    b'WMIh+8zcUR69zWPa1cfwKPPXWLwpJfg2KLU/cHHsuoJz71FuvChh4ypo6ImZ74X8XhxLCEAJ'
    b'K1b8oLKyqzGUF2yjf9yBLgNX2GBlcuiWjPjRMVmkD+6USSGZVPGbTJ8c19kgxVKUtxqT9SGv'
    b'XsPNez/HvNHaJJiSoSRWdU65fHqs1x8IDpPRB021IMQi1llSyM1eSFffR+57XkqVzsgkn0z3'
    b'IQK+adSIOOMAaUaD/zY0W+sYnHDJUSkn45df/qSaW4//ZfDSw+uP9k2AAQBNZtnn2K837QAA'
    b'AABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

table_relationship = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAoRJREFUeNqUU01LVFEYfs69586d22gTEgXuCsGCoEKpsPyI'
    b'DGa0RUYhBNFPsDY1pqXCGBUEBlKUG1tEBC4blckSJDVEJSQZDSNxEVRoDeTXfL2959yZFqOb'
    b'Hjicmfc87/dzhd3STwIKBCEELAPwecwxyzROunZgMVSL4s7o3GoiXZrMMJNcPiAgN8JB5MPf'
    b'NlCx0xYwDfHPtppEabxjK9fA+DlgPIC2yBIwelobdRaOTvxMMLUtRYWux8RlPpfQMfAd+BCA'
    b'bF95zJkIHiOF9l89aIdbIkEiTTuQgaX9qn0VqOzk4Py2b08QZfslwswXn9eIJCfpG5pDw5kD'
    b'KLEBp3UQfqdI1BQcRyINrKdADxsfYWahCaqr7nGg8cRP1FfthvTy0Ew+0shA/VbIEGdHATaz'
    b'zm3nm/FqogmcQwc4e/QCTJEAjwmiKzJLBkcweAPJdAbXggdhtYyivuiU4AB0ve4qJr48R3QG'
    b'GLlNePp2hbmbnGQDydQmsJwiihPRk+g8/SYXCH2kwD1Q33Qt3X0NqrsPEs2T+m05nePHNN+w'
    b'uWwvl+1IH/zZ1VQ6R3CxugTzP4YwFgP6b6LcEnH95uGy1VhNvm2lhJ43MfJahRiev4LYt2Go'
    b'zTfUONz/Osam2fkGyjnRlLd1kDbCATyLzkJyy+qkuWXuxcWxO6AXX0EvF0HhYS77gZZa2d7O'
    b'GFRX9q2I5uX4ve9i+pY5rR0qrkJ37wg8UknZLbuxC1Pv1/64ihNav8jxDcr+10PLw66OSTiW'
    b'IUyRYsd1LIWqlbxpOylLb0tEf0Tq8DJh8XQckVmyhM02V9AKPok4B/GrVRNlSyH3KsNW8ILx'
    b'Kc92WCXMJ4ptOvgv/BVgAO5JKpHTWRGVAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

table_row_delete = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAkZJREFUeNqkU99LFFEU/u6dOzOru07gWuBLD8UKRhBhCanR'
    b'Q2w/CaQnISj/gP4DyV1pqaDSCiIM3Uef7KVIkfKhH7a1LSYRBYkZIlQkybbtuts4czt3Zn9I'
    b'b9YHh/nmu+ece+6557LmxNRM/rfTYbuAKwEGBSJl9jdnjEHnQNDQ5nWNtwgVnB04js1iS2wy'
    b'YpkM3FbbKjyPAi9OAKljiE0sAy+PelbjpE8STx323FXFKlKgHH/hxzC4pkFQeQFuI7E67Ok+'
    b'vwtJa3pAR3xtDHHUTiVkOcOZ6A5wChYacG96Hj3RiKePP/qIniMtcEl/29uLbU/HgU+/IHUT'
    b'LvnzSiqjDiANQpASavASKeOhEHT6GuTTlHqAtlsjSLeGUay38NMM0RGYn2D27DmEU/fBNIH9'
    b'pC14TZdolw4yXaexeP4m2gwTpdsXsef6Hbzu60bAELUETRTcGU/A/v4Vnib9azO2NmMmEcOh'
    b'0RHMMQ7NakQpOYRd/Zfw5uplKVC7YehLi+CfF1BJqirQikUvl1n2M4INkK6D9fya30TlpJDt'
    b'PIXHySSY0ME482WV4Mkz5A52Y+xdHjsp0KgLorD3AD4MJdA1u7wPgb6HUmGdzCZzyUYz32QF'
    b'yfSXKp+ONMr84IB81RqWuJaRwcE01F5eBZpXjn8nem61OnEin63yQsdJpG9cQfv7FQQKWVil'
    b'HJjVPyH/aZTjU7BMzkQ9d5Zorrfbjlt7TKz8hjZMnEeouaq/OtUd1JDj6p9Wdm9o8mbgkM0x'
    b'KSX+B38EGAC2m+wilWllXQAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

table_row_insert = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAhtJREFUeNqkU01oE0EU/mZ/0nSjpqJgCQiCRSkePGjpqWKg'
    b'pRYqHkUwQsFb9SgIapMahUKPRTyoh4BC9SA9mFjFFukiFq1XsfUHrSK2NJRWIpLN7HPm7SZp'
    b'vFnfMjPfvN33zffevBVEhMT1p+9KZbnf8wGfAAFtCoTobyyEgG0AsYj5Hppg21CBNmM6ztCc'
    b'+mS2F33Ay+PAbB/ShW9q7eXRgPOL6rskgjilRiuIXZmkUvYYhvOfIAwtr1kp/Q1JAa8pSOEg'
    b'BQEfnvSR6W+Dc7kAVmAaUX75+PVezC8ewkBvK5ogkerewyNCdcz+nrZaPZjAtoCj1wTuDNzA'
    b'56VVxJSv2Xaw1QYPJ7K9ju04tthhvNJj6aXDTmL01BjefBmEygATrsSrDynk3Cn+TPtybjVE'
    b'lWC+C/cGZ9RGEfSPCsqezGDu+3kYTUqUyjvVZeLm9BRyZy9i7ddXTRGe6CPu7MaZWyMhmQFL'
    b'kaBUKYKiG646tI/0EEuVhQbfLtrXsLceXcBhKcfmzp04jaJ5l50Tsz4OJLoxfPsZc+pDiKpl'
    b'W0B765EQ++BG2nn1OSWzoPtve6gzDW6ScfdHrWEeuKs1PD6zUsPRS3niIpYlMJ0hdAwJtCda'
    b'mF1661ow43J5Wc2B3/OKat4R1oACBfH05KZbmRU4pr/WknkSr0idl3rI5xWE+t1twHprmwZi'
    b'lvhZrftBXVD8u0n+F/7H/ggwAEYOV/C7+oSSAAAAAElFTkSuQmCC')

#-----------------------------------------------------------------------------------------------------

update = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAtBJREFUeNp8k21IU1EYx//nbnfTzU0z05aucgMDCc2KhAiE'
    b'4VwUgRRG36IP9aEIDIOkYWA6JAqiD0F9KJJAAulrbXNZoGFi9g4VimZrvrR82ft27+69nXt1'
    b'NkM83Hs49zzP+d3zf16IJEkghGCjUe/ySqyKIMkJPpWKtPqcjtGMjcgAR5ePF0VRLYgS6AOG'
    b'8tQqBn3OBoVs6/BIl4/XYHI2hJefA1iIpHr72xwnZRsjT96r9tqK0oLwhWNVaKGOLSf2Ii2K'
    b'qzeQgQ+H/PidlHDGXglLiaHJ1um5uwqg411gIWr0fQ2iyz2Gtz8WAemfBIYSQqEYXk8sont4'
    b'Gg37y2HQqs/Xuzw7FACltddWmJCCCjotC3OhXjmUGd+f3W9Mzkz2MNEIopyAgYkQ6qrKIKTF'
    b'm8s3EMUreUY95qI8WC6JHt/HMSYrsFODT90Dt063xoP+HsJx+BnmodXpaARJ0zKAEG2II8hh'
    b'NfTqIkbuNZ+i51NZiZDX/vePrzlFLoUcrQZhgQGhOhWA/K+lpIC8XA34RBLhwNiHV66mQ9mp'
    b'dHT1qWJB/1QqHkceBSzRgJJMEOXFnyRQnK9FWUk+zbtHxcVCo9kAmu6wrcOdY95SoPhFeAJZ'
    b'5YoEeSEiwgFbC40QBPEG1uQBoDWi21ZkCFlLN2E+AfA8T6HgFAAfW/ImYzEQRg1ruQkFhtxL'
    b'tuvu23aX15oB0EJDo20PazaboNGokYhGEZ//9UgBBEaed85Pz4JlVfBHgaN11aiuNDfTQ+NZ'
    b'GvApKMAfA002EJyZxdCds+0KYNzXPZxYnOud/PINsbSEQILB7l1WWfeaYgKrRYrRwFykh8W0'
    b'OUy3p0lWM22va33yQF9YXF9m2YktpmK86R/Ei7bDitHu8kiyDEluFurPMIwMTZP/utFSceTc'
    b'QVON/SKbazgg7/c5HRnjvnUaVSLrtDMtMZTS17jyPbpRq/8VYABm7ivbCz/37QAAAABJRU5E'
    b'rkJggg==')

#-----------------------------------------------------------------------------------------------------

watch_window = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6RDQ2OENGNTYxMDdD'
    b'MTFFM0FGOUJCRTk2Mzc1ODMxMjgiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6RDQ2OENG'
    b'NTcxMDdDMTFFM0FGOUJCRTk2Mzc1ODMxMjgiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDpENDY4Q0Y1NDEwN0MxMUUzQUY5QkJFOTYzNzU4MzEyOCIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpENDY4Q0Y1NTEwN0MxMUUzQUY5QkJFOTYzNzU4'
    b'MzEyOCIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PnZsAM4AAAKZSURBVHjajFNbS1RRFP72OfuMMzqOTk5EIDqZQ0Ez'
    b'yNB46SXEsNGgMYp66WdUEoOUhZaO4m+IHnqT8PLSdJGgZtIoG80KHEMjKMHRYCTyXFv7xDEf'
    b'urhhs1l7rfWd7/vWPqy6P72hGWalZVnYzWKMQZGlb7LE/CLmorkv0QTDNCH9p9mkLUsSesZn'
    b'KiUmExgB6NRY5ea4nP4ETgjsL82Cn04IwydrIHpckAUfAWDB71ZwKOCFzGCj7iC8DSgADFHr'
    b'cdlABmVMxkkCBa21btq12O1SqUchBsniOLjjXX5xEZBkmKYBYShjEj4uLaKwtmazEHeBQADx'
    b'zlPQyS2Vvv6DKZAc71/OTCM1OACfrwIry8soKyvDemEdsaYWRBubcZTOQqFg1wqAZPE+NCZb'
    b'28Z3nTkLhXN4vV7EGpvg8ZTauhVFgYu24nL9NpTY6STBFCY6l5MTY6RARm72NbZUFeEjEQSD'
    b'QWQzz7cbReyYa9rCdgDEOzrwLJNFsK4OmqZi8/sm6utDCEciqPD5sEZeGLpu11ZbGzaAYMid'
    b'sT1MPwAnBiNDKSrUYJJpnCtobWtDItGFifExzM/NwdJVXHQp0FxuizETXJF+IZyOt2M6m0Wk'
    b'/QL2hxrsyX/+MIvixhLu3b2DEi4jcuIcqg9HIZEHX/JzeP+UZJdyViy/kUZ4ZAol9LiCkUZE'
    b'D3ixz+/BwYYWLORySC5X4W3uDeoojgbLsddfgtpwjEZOz//rtc7jm73xWP7m+ZimG5mFJ6NY'
    b'JXFyBcfC1Cg0Xc+sXE/ExPmO4lWh28cx/3gUqqq9YjW3H2GLHsWl4iS6+4dDV7uvvLBMc4/t'
    b'tSStD6SGmnt7kvnevlv1lJt2cqDcYGro2J/+HWGAMx1he+5fuZ8CDAD/Sv46ZbrYXQAAAABJ'
    b'RU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------

image = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAexJREFUeNqUU8tuEzEUPfY4nsyrSQNqWfR/WNEdK/b0D2CN'
    b'1C76CZQlYsOeil/gD9i0QuIhhRaFJnSSTmZsju28JkIIrnRsj33vuefeqxGPT9+/rBrztDYA'
    b'BNpmV0vrTklAq+js7bOHRzg8Obe31tpr4uoP+L4F5+f8D0/ecbVQNRlTEs9ESC/SDCIjdgrI'
    b'NPe7yLgXub9XWkO/OoNXTFN2obtx6noDyN1diB6d+wVQZEBCsm7qgZhw8jcKU25Zld+n44Oc'
    b'JEUgcUoS3mkGdlxwTKmVT4ZNAscmuhJiL4XcS0iQUDqRJiGz4t5J4HPbptVW5cKdAnmfDgMS'
    b'DOjs9l7oBWIq0jk9iUayArNNEOSLgSOIIe4xmBAsA9UNzPUFmkmJ5uIS5scd5OUIxfMXDBBr'
    b'Ak/iJPe6zEzJegpz9ZHEVXiMDOT+Dp1mED8ny4gFAfVE7jPXRApbfqXUG6pgw9wY55Q8qmFM'
    b'BVHOeae8/3IO6xK6Gmb0mSSU2aeaImI5ESwT2hmH3SEkg6QJue1GE/0ov32CmfH9gI27nQIl'
    b'FcQdnmvgVwUzvoMdT/0ZLQU2HLIPJUzraW1RGKA3ufonFgRKbnXzH20VNx8P3zw6Pn/SGLMk'
    b'/au56UVSop4MXy/7d0Ds4/9tyL/xy28BBgAMXMtNyzRrZwAAAABJRU5ErkJggg==')

#-----------------------------------------------------------------------------------------------------


folders = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAA2NJREFUeNrEVztvE0EQnt3bteMYiSBFoiOCBhqgSBpeVUqQ'
    b'gIYKgaCBIkhU8BegJBQGIagiAT2BDhDIoolIHIGCEA+FFCgmjiAJ+HyvZfbB2efn3cnIK63s'
    b'27ub+Wbmm2/3iBACBjkoDHgQnLxUmPwhfGe7CAK8FJHbhFLwgT0Zn3pxGhe8fgNgOPPS+cHL'
    b'D9A82hckCo9ZUCpcOIH/cjg3/weAjIrcc8H5cAPjt4xnOXzIjp0Dr2bD21uHNgghDciaUimX'
    b'qAW+sGYxW6fiZouF/wIXBM2iJa6tyUoIHwJ7DcanHmqflOh7lEB7BBwWC2ePJ8lWHYCwMQCu'
    b'lwjVXBAY0fornC+Vf7m8vPAJ1lfKbQFQxoFlhuXVUEIAMmIPKEcAlDelWIQBfp1bgpF9Z2DP'
    b'yaO4LEzUDc/h+6W7F9vXqCsAaYi4sLLwGdaWy02dYMwjOXcdGIORUSxupYhZeRPxQ7Dkmb3X'
    b'QHdSMhIaRXDR+XeYuPoY+eBHu0EXAPzyUwTiQrDxDggblk1qYhcKAAS1VF1gSuDqyH0HvC/T'
    b'uhsaUkyQANRiShdoLq/fIWF6JDwMwlP302VAdQ1aDP4g93KGjA0AUA+Wns9B9eeGrn+0QOrV'
    b'nft9BMBSAiAGgKiiM0nEuh7I/qecovNfMHFlxpToX2m0c7AsmC+cByszlLIE4IYZoNgJQm0T'
    b'dQAERUZF7qNgfbzZVrAC11FX89OHV+MKVlMJZEBIJIuHxAvfwvqrzAuni2A9SixYDQB849AG'
    b'IgGIRgJKY+ZRZHo/BateAouY3bmmOECaUXNm1vorWAoAkaliLiLDumblSr5112YUM0OVXvRT'
    b'sCQAUdnyiot3Zo6wbBZK9+5DEIjWc4GqAlOK2VOwVmfRgYOC9R5B5+qaIbMhpGDZkS6wJ6+/'
    b'voS/o1FdaBl8/vaxZ5qsnQXLsFCD5kOtZRI0opjSYRXnN5zlHpvIDn27u2BFgUCrYCmtscP7'
    b'zFjcjH3a6SJYvUd7AAmPkJ0FKw4AosrghAxjibevboIVK4ZAERnSA+gsWLH8Exm7kxZAD8GK'
    b'/TXihmeJRAB6C1bMkbHCc0MiAILQLRSsbZ0FK14WKQZS+e0XIWEBR3Du1nqQLvNNTF6T+pPE'
    b'EDc5z/Thg0goFmsRHPDH6aA/z/8KMAAV2HjZKbRagAAAAABJRU5ErkJggg==')


#-----------------------------------------------------------------------------------------------------

setting_tools = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAACK1JREFUeNqsVwtQVOcVPnvv7rIg4b0IiCCIyvKoCtSmUbFq'
    b'rXHU6sZHaMdBbWo6mWkTjaEq+EzAIRaTMSapnThl8rBRUTCdxrRNwmNRpKCTovJeQYF9L7vs'
    b'7t33q+e/uZusiMi0vTNndvfe//7fd17f+ZcHU7y2bd8RmZiQeEIkEhUnJCSIkmckwbRp04Cm'
    b'aZDfuwc9Pb2yk394cyUu9R19vWIvRVG7vV5vklgsBo1GAzwePvB6a+0OxwFc14/r/GRf3hSw'
    b'6QNlh/4oEAh2STdugPm5OcCjKFAoldDa+i/8VEFfX1/je6dP7cC1hvLjb/YlJSQmLFu+FMRx'
    b'ceD3+xGcB06nE/r778HX9Q2gUAxnnnn/vT5Cgv8k8H0Hymry8/IQez0LbGWsUN/YBLLmZujq'
    b'7KxkGMtws6ypBde636io7Js3d25CYeES6Lh9F65fbwWMBGvx0+MhNzsLkpOT4IOzf+7B9SI0'
    b'52QE6P2lB2vyC/Kkm6QbYXTUAAajERoQvLe3V/9W1YktuEaHZkZj9pbsf35GYhKCL0aCMvB6'
    b'PIBRA7PZTDyGru4uaKivZ4NO0xTZP2wyAiTs6Hk+gm+AB0MjYLVZoalJBnK5XIHgW3HNEAk5'
    b'mgtNGBERcZSEveN2JwtOUTRbHyaTCV4/emQNiVDQ/sbAF2pi8MM1PywokG56bgPcfzCEm4wB'
    b'hXmMjY0BxmL5hgPXoNnQPGghmOvp8XFiUKvVbM4pigd8Pp8tPrwG0e4EGfltJQ/GR4B/8PCx'
    b'2vy8hetJzgcG72MIGXC5nODxemHr5k1AU9S6iMhIqDpRKQ16T0CKzWyxAEEkBIj3QqEg2GPt'
    b'RKEeH4FQHo/iwAcR3ITV6wCnwwl6/SgW3nXY9JyUbL6OrA1+kRDg03y2rb4F57M18KRGo8YV'
    b'XXV+3gJQqtQwNmYGu8MFDocD7IQEtpFGq4Ov6htZMK6Kv7u8HpdqcHAA4rHvBQI+kkDj0+D3'
    b'+SYlQOjxy49XXhGL49empsyEjNnpbN7Dw8MR2AkuNAcSIWlAYYGBgUHAZINSoag7dKiMdIIX'
    b'LXb3nr11RUVFS6Ojo6FfLmfzLwoJATWKUHt7O9uKLCBbHxRUHi8PIQXM58K+9sVf72QX1Dc0'
    b'wSCGnxRP6qw0BHaBx+1inw0NDYNIJGTTMGbQSZ+ifed3lx7a9kbpgTOr1q5fOm9uBvwb+59E'
    b'CBWTJZGeng5ZEgn7WyCgQaVUw+W6ugGuDVkCQovF1FRzqXaZBBeGhorYwFgsDPZ7H+h0GvY3'
    b'2TQyIgIWzJ8Pt9rbICsnGz4OX7Y55sjnUs8coPN/kAVtHZ1gt9vQ7Kz3MVFR7HtsgaIedPf0'
    b'QHd3N+rB13uDU/AUWtrekn2nM+dJCmfPSQc3ei2XD0BvT3d9W1vrJQFfwMMo+NNSZm7ZuGHD'
    b'8qi46fDqN27Ys3YltKkYaB9SQYpbBa9m+GBIo4fm6y2KyMjIGKyU0GlhYeiMhQXDom754E9n'
    b'9uHXB1wbu3hcK0ahpSCJt2fPzihMTk6Gjo4OOFS2/2m8r+dEhJR0zNbNm4/1Ltq15rfPLoO7'
    b'OjuoGQe4/RTcvDcI62g5+O42as+cPftLrjYoHFzhqA1WTi9MHHBAwPw0mV5EEsmNGy3XWyVZ'
    b'ObkYrpmMxdRy7VpzNd5XBeQ2dEVxjHXFS1UlaxbDba0dVBY7uH1+8KBFhEeBbNgAjW+X/AzX'
    b'3kdTEvIMwyg5DdBw0m0KVsXgJiVkotGS0CI48SCKR+LHi3np3dnp2Xn9Fet/DFflRlBaHCyw'
    b'G/10+3mgwDkR5jXBJv2Xn+07fKQI33EEYfgfO3CCtYQLC8OBkzDZyf2Y37yThuDy8vXPsOAq'
    b'xo7gwIJ7EFyJ4F79AHy1LRskknmZs+LFmX+vb6idDHiiCEwoVLH7zhcvypxb/fLyhfDFOHAv'
    b'gqtxTngMD+BUngBong9+lL8Adv61D9r1PjCZzVd0x9Zt4fIPU5Hih57FlJzbvnx+TnXZswvh'
    b'ar+BzXkwuM5shGGtEiS3qv9p0KlBgAKz8cN2GKMi4C/bl8KyeWkb4w7WXRwX6cem4CHw6NfO'
    b'Fa9YOL9694psuHDXwFa71/89uN5sAKV6BIwflhXdbv7yaphQMOtvguw0QXwa/H5VDvxDboFf'
    b'LEgGtdUr0UlW5dpkFy5NlJKJUsCPLqu7+GJhgXRtbjJc7BxFcOcE4MNgvFD5vO1O002u4BLn'
    b'vnPj5ic7noa3GrVgRS2ZFRUGW7Nj4FRDJzR29dfpy6UB6X5sBOjo0tqaPasXS3+amQgXu0ZB'
    b'8zjwTyu22O42t+E76kCn8HJWFFzptaZ6qXAghx6H2wMjFg/8alEqaDAS2gkiQT/keWntJQJe'
    b'mBEPNei5xjoxuLOrpcJU/8nnHLiT0xK/raX2RmjukmwPX5gaIopk42t3TU4iQIAWl9We3fWT'
    b'RUUr0fNHwbEvGQsoVA/A2XntuP7T8o84gXIEeUNIuJkbn7WG5CyRuGlhqjD0ySQCBKbFrnnh'
    b'YunqBVhwweB+1nMGDyQjygFw3JFV6M8f/5gDt48rqu8UdTISLyAJrc0n0WevzrM2na8JtKFo'
    b'jjgKH+DOmPNvW+178Psj/eA2qGUIfo6TWCsHOP7yBhRUdXLnHkbRI9Nqh8GKwmtFJRg2OeBy'
    b'txFKVmXhHwIBe6oKEKDUFhtQOJYIOLFgcM+oSqaq2v4Kl/PHgU9KwoYkbEhCybjgldpbwGOM'
    b'TWTABVIQxiv4+ZasmXFRGjsfnLiFGY/hQ4p7qHKqZtXJHXtwzTA3lLxT+DflfyQd/JBUUVg0'
    b'shqCEXmnTFNV/DI+Hw3oACYKMhLKLtfyRGEpeKJmj05e7fAXqlO7DnJDyThFcJhgwKUkvvbR'
    b'aaE4+RmXbqRFVVX8O27PsQABMutj0WZwk5DiRqaRK7ixyfR8iiQCU9bM1RHrULASCrhzmpBT'
    b'SB/XZvb/wvNH1JU7xgs4x+z/g0P/3+s/AgwAdGqB/H5XELMAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

add_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODI4RUQzMzU3NkNC'
    b'MTFFMkE3QUQ5Q0UxRUYxQTkwNEEiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODI4RUQz'
    b'MzY3NkNCMTFFMkE3QUQ5Q0UxRUYxQTkwNEEiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4MjhFRDMzMzc2Q0IxMUUyQTdBRDlDRTFFRjFBOTA0QSIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4MjhFRDMzNDc2Q0IxMUUyQTdBRDlDRTFFRjFB'
    b'OTA0QSIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/PqOUi98AAAIcSURBVHjajJJNSFRRFMd/9+PNmwwNxZBCbS0kuIgs'
    b'wSBoG7nRbbsg2pTYx6YWFSENQou2EW21oHaBqVFE2KKNUaJFHwyWFFI4zVjjvNs5T/u0yc7j'
    b'/967557/uef87zETF/aSJAkhqbwD0ySgugXFiLGuz1oroQav5Er5S+g8eIYPz26J0/6Dn9DY'
    b'dqB38trZQBRLHocNyfJw9+FBSvlxamo3sbG2rip0X+M0XnmEgJdX7/zzKZLQQlp+YB0LLEm8'
    b'8nTljfQSxVnmp25KS5b1NAjSRlN7D8pTM2Pnu0OlXJZfm/ZvTPUEQUpWHSDBRRHWeeODiNh1'
    b'6BKv7w0J31dNYL5fQrJM654BHl7pl3i5BS2pXFzApaevbcHIY8Uf4eSRfVvBl0rEiXgEIqIh'
    b'fP2E804yujUJlBSbmOHCOGNLMxjpwExcpau+mccNebRmQrmA99HqDJjfTs+YiOuLd5mumWF/'
    b'B+zaepzJtzmezOaJP3LZpgRN4KJV+B+IZJ11MaPFaba3QuEztDdcpFCAtpZUzyPpXZikiM8I'
    b'OXIC/xMZRyR+FW+nnHysc2VIjsp3x5aTOkcrc+BDCbLZvyivLWRQacZnc9x+muP0vsC5O4YN'
    b'kldHwUvY4qPR+7V6G38OoQ0ioOi/u6GZF3N5tjXCg1enxA8v56C0wA1VrCMVex3rGeJEXT19'
    b'WraOipJHBug3/L+JjGz+Zf1e8OabAAMA4Yi/RrV3XFkAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------


edit_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODlBN0YyMTE3NkNC'
    b'MTFFMjhFOEJDNDUxRkU5OTMzQTIiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODlBN0Yy'
    b'MTI3NkNCMTFFMjhFOEJDNDUxRkU5OTMzQTIiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4OUE3RjIwRjc2Q0IxMUUyOEU4QkM0NTFGRTk5MzNBMiIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4OUE3RjIxMDc2Q0IxMUUyOEU4QkM0NTFGRTk5'
    b'MzNBMiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/Pi0WmboAAAJDSURBVHjapFNNaBNBFP5mdmJD8RdME5CoYKmIFArR'
    b'qq1FwaJWBQvVgKgHD5YeBMGDB6MNie1NpYoeqngQhCKIxB9ENi2ItWADtdKggvHiQUIkKKEx'
    b'iW4z49tJU6KkFXSWt8zO7Hvv+773HlNK4X8WK2+Gw9uT9OmpOKqy7GQq1d770lM+EfbLDG5V'
    b'm4+dQ/r9Q/LnC/hLrNxw0G0Ww2p36JXOxIbDrfdau/v9mQ9PKD4HY/MjsOkySCxrOICxmwFC'
    b'MuYRdOpPfYxDKm+J0V8lkSgkpgiMdGsKjHM4apxIxSOUnWMhDRRRUHIGdRv3QxYLJRFH+tpU'
    b'0bJoyzX/+Sjoaqki5EwOvhMD9K+Ea90uJggKWroH8OnFZfIX1QPMOkMWUL83iHc3flAAS19x'
    b'G5aV+wqDsttW/QEMCrB+TxiBa8+wtNGL7ytq8TrwQJGIDOpnBoYwCIHxhwZK8wah9O7oxdmr'
    b'Jo76u3D36RDcWTea0nldNygrCyEcMAyjwigz3RlMwdvej4lLhxE4Xo/IYxM+XzMm82/RPNiz'
    b'ieuMdgDDMWuiZERHcIVVO0OIXdyHls46LJ88jUMN3xB5FEW4p8uGOKE7kckcxCLHXHdrxQm2'
    b'a9t5ZKIn0Ra4AJkhuFNnMBobwuDt5xgJdWCuD4TKA07nb/UGiU6scD/ugtdKoKNxMa6Pr8ap'
    b'WyaysSukam15Fth0LDq6RDdJRdmUVcCWtWkkkha+JMex5jPHkeAdmH2d4KLGLvl0eRqb7Cr9'
    b'wyQTRrz5JcAAGhHev5SFI9MAAAAASUVORK5CYII=')

#-----------------------------------------------------------------------------------------------------

delete_package = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAGXRFWHRTb2Z0d2FyZQBBZG9i'
    b'ZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tl'
    b'dCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1l'
    b'dGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUu'
    b'MC1jMDYxIDY0LjE0MDk0OSwgMjAxMC8xMi8wNy0xMDo1NzowMSAgICAgICAgIj4gPHJkZjpS'
    b'REYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgt'
    b'bnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8v'
    b'bnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNv'
    b'bS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEu'
    b'MC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9w'
    b'IENTNS4xIFdpbmRvd3MiIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6ODYzRjE3Qzk3NkNC'
    b'MTFFMjgwQjhGQjU5OTExODg3MjkiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6ODYzRjE3'
    b'Q0E3NkNCMTFFMjgwQjhGQjU5OTExODg3MjkiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6'
    b'aW5zdGFuY2VJRD0ieG1wLmlpZDo4NjNGMTdDNzc2Q0IxMUUyODBCOEZCNTk5MTE4ODcyOSIg'
    b'c3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDo4NjNGMTdDODc2Q0IxMUUyODBCOEZCNTk5MTE4'
    b'ODcyOSIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94'
    b'cGFja2V0IGVuZD0iciI/Pj9gWJ8AAAIeSURBVHjajFI9aFNRFP7uz0ueDXZS2qWFLoVSlCwF'
    b'qUVMESxY0KVxcRbRLYhDB4UMOgmCDg52cZLWgkIXm0hAHfxBOoTSQWtpM5hoW2kaY2Nf7vHc'
    b'2wcJpE09cODd++73nfN95wiEkU2PFAHRxYmDg2zOnLv9Lpm7m4glJnO/tb2ev3OKhq5MYn3p'
    b'JeNlG7zBsYGLE/P1NDFY2SuVTZ+eHrl2b7Cy8gpe9AgiUZ8zum96kSiC8jf0j11HovPLwNNc'
    b'4bkG0UTpax6GeuDaJxwShB1+z7gkHy5rISVX9lHKv4Bw7bf3gFhG14lLsDgbmlFYnJviT+n0'
    b'C3EwARE5H9ZXp6A8b4+AjMHw1QdYfXOf8botwV4HAXrP3MT7J6mQgBl3q5tQrvo+EpjQXSvp'
    b'miSSCOplGC1CCSRAf7egtOKHqpVAMkFEovK6gNqnH/zcYAspdPR3NDyg3Qq09sIdaCLgT+FJ'
    b'bGfXECsYnBw7C3i8OkGAlcUlfL4w9Ei7V5ZAea1LxOTSU6h++I7B4TjoF3dgAgil0dfTjY3N'
    b'jRtuE4WpQke8Rtnm9qMsSxDE6DhwPtn4m5kGLeTh9kDTH8D3W023EiLKVQxmHoOePYSpG0g2'
    b'VPAYpVKwErY/Zt4etdOgFjz7wx7E2LDlUhV9nSzJjpJJlssBirVg1nYUt0M6bIHnRuO3umN+'
    b'kkKRxZ3a7HhmISXw/9HLebzp/JNz7Z8AAwDLYLxgFHNxHwAAAABJRU5ErkJggg==')




# In the name of God
# -*- coding: utf-8 -*-
# Windows and Panels main Frame File
#! /usr/bin/env python

from Allimp import wx , os

#import wx
import wx.dataview
import wx.aui

from GUI.proman import Mymenu
import Database.MenuSet2 as MS


class MyLstPnl2(object):
    LPn = []
    PrP = {}
    def __init__(self):
        self.MyMenu = MS.GetData(u'Menu2.db', u'')

        self.lstpnl = self.MyMenu.AllPanes()
        #self.hdlpne = self.MyMenu.getHndid('5555')
        #dirfil = os.listdir('./GUI/AuiPanel/')
        PP = self.MyMenu.ProPane()
        LstPPane = [P[3] for P in PP ]
        dirfil = os.listdir('./Src/AUI/')
        for f in dirfil:
            for p in PP:
                if f.split('\\')[-1].replace('.py','') in p:
                    self.PrP[p[2]] = f

            if f[-3:] == '.py' and f.split('\\')[-1].replace('.py','') in LstPPane:
                self.LPn.append(f)


        #self.LPn.remove('PAui.py')
        #print(self.LPn,self.PrP)
        #print(self.lstpnl)

    def GetAuiPnl(self):
        return self.LPn

    def GetAuiPro(self):
        return self.PrP

    def GetAuiInfo(self, Pname):
        myInfo = wx.aui.AuiPaneInfo()
        for pnl in self.lstpnl:
            if pnl[1] == Pname:
                D1 = self.CreatData1(pnl[10])
                D2 = self.CreatData2([pnl[12],pnl[13],pnl[14]])
                Dok,DL = pnl[15].split(';')
                x,y,i,j=pnl[16].split(';')
                D3 = self.CreatData3( [m for m in DL]+[[int(x),int(y)],int(i),int(j)] )
                D4 = self.CreatData4( [pnl[1],pnl[9],pnl[3],pnl[11],Dok,pnl[2],pnl[4]] )
                myInfo = AuiInfoSet1(D1,myInfo)
                myInfo = AuiInfoSiz1(D2,myInfo)
                myInfo = AuiInfoDok1(D3,Dok,myInfo)
                myInfo = AuiInfoGen1(D4,myInfo)

        return myInfo


    def CreatData1(self, S):
        set1 = ['caption_visible', 'close_button', 'maximize_button', 'minimize_button', 'pine_button',
                'pane_border', 'show', 'gripper', 'center_pane', 'default_pane', 'toolbar_pane', 'moveable']
        data1 = {}
        i = 0
        for b in S:
            if b == 'T':
                data1[set1[i]] = True
            elif b == 'F':
                data1[set1[i]] = False
            else:
                continue
            i += 1
        return data1

    def CreatData2(self,L):
        set2 = [ 'best_size', 'min_size', 'max_size']
        data2 = {}
        i = 0
        for s in set2:
            w,h = L[i].split(';')
            data2[s] = wx.Size(int(w),int(h))
            i += 1
        return data2

    def CreatData3(self,D):
        set3 = ['dock_fixed', 'floatable', 'bottom Dockable', 'Top Dockable', 'Left Dockable', 'Right Dockable',
                'pane_position', 'aui_position', 'aui_row']
        data3 = {}
        i = 0
        for s in set3:
            if D[i] == 'T':
                data3[s] = True
            elif D[i] == 'F':
                data3[s] = False
            else:
                data3[s] = D[i]
            i += 1
        return data3

    def CreatData4(self,D):
        set4 = ['name', 'caption', 'float_size', 'resize', 'dock', 'docking', 'layer']
        data4 = {}
        i = 0
        for s in set4:
            data4[s] = D[i]
            i += 1
        return data4


def AuiInfoSet1(Data,myInfo):
    #myInfo = wx.aui.AuiPaneInfo()
    if not Data['caption_visible']:
        myInfo.CaptionVisible(False)
    if not Data['close_button']:
        myInfo.CloseButton(False)
    if Data['maximize_button']:
        myInfo.MaximizeButton(True)
    if Data['minimize_button']:
        myInfo.MinimizeButton(True)
    if Data['pine_button']:
        myInfo.PinButton(True)
    if not Data['pane_border']:
        myInfo.PaneBorder(False)
    if not Data['show']:
        myInfo.Hide()
    if Data['gripper']:
        myInfo.Gripper(True)
    if Data['center_pane']:
        myInfo.CenterPane()
    if Data['default_pane']:
        myInfo.DefaultPane()
    if Data['toolbar_pane']:
        myInfo.ToolbarPane()
    if not Data['moveable']:
        myInfo.Movable(False)
    return myInfo

def AuiInfoSiz1(Data,myInfo):
    #myInfo = wx.aui.AuiPaneInfo()
    if Data['best_size'] != wx.Size(-1, -1):
        myInfo.BestSize(Data['best_size'])
    if Data['min_size'] != wx.Size(-1, -1):
        myInfo.MinSize(Data['min_size'])
    if Data['max_size'] != wx.Size(-1, -1):
        myInfo.MaxSize(Data['max_size'])
    return myInfo

def AuiInfoDok1(Data,Dok,myInfo):
    #myInfo = wx.aui.AuiPaneInfo()
    if Data['dock_fixed']:
        myInfo.DockFixed(True)
    if not Data['floatable']:
        myInfo.Floatable(False)
    if not Data['bottom Dockable']:
        myInfo.BottomDockable(False)
    if not Data['Top Dockable']:
        myInfo.TopDockable(False)
    if not Data['Left Dockable']:
        myInfo.LeftDockable(False)
    if not Data['Right Dockable']:
        myInfo.RightDockable(False)
    if Dok == 'Float':
        myInfo.FloatingPosition(wx.Point(Data['pane_position'][0],Data['pane_position'][1]))
    if Data['aui_position'] != 0:
        myInfo.Position(Data['aui_position'])
    if Data['aui_row'] != 0:
        myInfo.Row(Data['aui_row'])
    return myInfo

def AuiInfoGen1(Data,myInfo):
    #myInfo = wx.aui.AuiPaneInfo()
    if Data['name'] != '':
        myInfo.Name(Data['name'])
    if Data['caption'] != '':
        myInfo.Caption(Data['caption'])
    if Data['float_size'] != '-1;-1':
        w,h = Data['float_size'].split(';')
        myInfo.FloatingSize(wx.Size(int(w),int(h)))
    if Data['resize'] == 'Resizable':
        myInfo.Resizable()
    if Data['resize'] == 'Fixed':
        myInfo.Fixed()
    if Data['dock'] == 'Dock':
        myInfo.Dock()
    if Data['dock'] == 'Float':
        myInfo.Float()
    if Data['docking'] == 'Top':
        myInfo.Top()
    if Data['docking'] == 'Center':
        myInfo.Center()
    if Data['docking'] == 'Left':
        myInfo.Left()
    if Data['docking'] == 'Right':
        myInfo.Right()
    if Data['docking'] == 'Bottom':
        myInfo.Bottom()
    if Data['layer'] != 0:
        myInfo.Layer(Data['layer'])
    return myInfo


# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################
import os
import string

import wx
import wx.xrc
import wx.dataview as dv

import Database.MenuSet2 as MS
from GUI.MainTool import *
from AI.Generats import GenrDemo

from Config.Init import *
import Res.Allicons as icon

_ = wx.GetTranslation

###########################################################################
## Class MyPanel4
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 558,450 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D|wx.SP_LIVE_UPDATE|wx.SP_NO_XP_THEME|wx.SP_THIN_SASH )
		#self.Splt1.SetSashGravity( -1 )
		self.Splt1.Bind( wx.EVT_IDLE, self.Splt1OnIdle )

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.MyMenu = MS.GetData(u'Menu2.db', u'')
		self.DoMenu = MS.SetData(u'', u'', u'')
		self.Ttype = 'N'

		self.lbl0 = wx.StaticText( self.P1, wx.ID_ANY, _(u"List of toolbar:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl0.Wrap( -1 )

		Vsz2.Add( self.lbl0, 0, wx.ALL|wx.EXPAND, 5 )

		# self.DVC1 = wx.dataview.DataViewCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )
		# self.Col1 = self.DVC1.AppendTextColumn( u"Name ToolBar", 0, wx.DATAVIEW_CELL_INERT, 178, wx.ALIGN_LEFT, wx.DATAVIEW_COL_RESIZABLE )
		# self.Col2 = self.DVC1.AppendTextColumn( u"ID", 1, wx.DATAVIEW_CELL_INERT, 45, wx.ALIGN_LEFT, wx.DATAVIEW_COL_RESIZABLE )
		self.TTC1 = dv.TreeListCtrl(self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0)  # wx.TR_DEFAULT_STYLE
		self.TTC1.AppendColumn(_(u'Toolbar ID'), wx.COL_WIDTH_DEFAULT + 95, wx.ALIGN_LEFT, wx.COL_RESIZABLE)
		self.TTC1.AppendColumn(_(u'Toolbar Name'), wx.COL_WIDTH_DEFAULT, wx.ALIGN_LEFT, wx.COL_RESIZABLE)

		Vsz2.Add( self.TTC1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz0 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn1.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_NEW, wx.ART_OTHER ) )
		self.btn1.SetBitmap(icon.add.GetBitmap())
		self.btn1.SetToolTip(_(u"Add"))
		Hsz0.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn2.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_UNDO, wx.ART_OTHER ) )
		self.btn2.SetBitmap(icon.edit_button.GetBitmap())
		self.btn2.SetToolTip(_(u"Edit"))
		Hsz0.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn3.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_DELETE, wx.ART_OTHER ) )
		self.btn3.SetBitmap(icon.delete.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))
		Hsz0.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn4.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_PLUS, wx.ART_OTHER ) )
		self.btn4.SetBitmap(icon.separator.GetBitmap())
		self.btn4.SetToolTip(_(u"Seperator"))
		Hsz0.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn5.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_MINUS, wx.ART_OTHER ) )
		self.btn5.SetBitmap(icon.update.GetBitmap())
		self.btn5.SetToolTip(_(u"Update"))
		Hsz0.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn6.SetBitmap( wx.ArtProvider.GetBitmap( wx.ART_REDO, wx.ART_OTHER ) )
		self.btn6.SetBitmap(icon.information.GetBitmap())
		self.btn6.SetToolTip(_(u"Info"))
		Hsz0.Add( self.btn6, 0, wx.ALL, 5 )

		self.btn7 = wx.BitmapButton(self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize,
		                            wx.BU_AUTODRAW | 0)

		# self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'accept_button.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.accept_button.GetBitmap())
		self.btn7.SetToolTip(_(u"Apply"))
		Hsz0.Add(self.btn7, 0, wx.ALL, 5)


		Vsz2.Add( Hsz0, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		self.titr = wx.StaticText( self.P2, wx.ID_ANY, _(u"Group:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.titr.Wrap( -1 )

		Vsz3.Add( self.titr, 0, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.grup = wx.SpinCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 45,-1 ), wx.SP_ARROW_KEYS, 1, 9, 1 )
		Hsz1.Add( self.grup, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl1 = wx.StaticText( self.P2, wx.ID_ANY, _(u"ID"), wx.DefaultPosition, wx.Size( -1,-1 ), 0 )
		self.lbl1.Wrap( -1 )

		Hsz1.Add( self.lbl1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz1.Add( self.fld1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl2 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Access"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl2.Wrap( -1 )

		Hsz1.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld2 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz1.Add( self.fld2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.codgnr = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		self.codgnr.SetToolTip(_(u'Code generator'))
		Hsz1.Add( self.codgnr, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl3 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Name"), wx.DefaultPosition, wx.Size( 54,-1 ), 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld3 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz2.Add( self.fld3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl4 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Icon"), wx.DefaultPosition, wx.Size( 54,-1 ), 0 )
		self.lbl4.Wrap( -1 )

		Hsz3.Add( self.lbl4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.IcnFile1 = wx.FilePickerCtrl( self.P2, wx.ID_ANY, wx.EmptyString, _(u"Select a file"), u"*.png;*.bmp;*.jpg", wx.DefaultPosition, wx.DefaultSize, wx.FLP_DEFAULT_STYLE|wx.FLP_SMALL )
		Hsz3.Add( self.IcnFile1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz3, 1, wx.EXPAND, 5 )

		self.btmp1 = wx.StaticBitmap( self.P2, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz3.Add( self.btmp1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL|wx.ALIGN_CENTER_HORIZONTAL, 5 )



		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl6 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Short text"), wx.DefaultPosition, wx.Size( 54,-1 ), 0 )
		self.lbl6.Wrap( -1 )

		Hsz5.Add( self.lbl6, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld4 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.fld4, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz5, 1, wx.EXPAND, 5 )

		Hsz6 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl7 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Long text"), wx.DefaultPosition, wx.Size( 54,-1 ), 0 )
		self.lbl7.Wrap( -1 )

		Hsz6.Add( self.lbl7, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld6 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz6.Add( self.fld6, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz6, 1, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer(wx.HORIZONTAL)

		self.lbl5 = wx.StaticText(self.P2, wx.ID_ANY, _(u"Type Toolbar"), wx.DefaultPosition, wx.DefaultSize, 0)
		self.lbl5.Wrap(-1)

		Hsz4.Add(self.lbl5, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Rd1 = wx.RadioButton(self.P2, wx.ID_ANY, u"Normal", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz4.Add(self.Rd1, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Rd2 = wx.RadioButton(self.P2, wx.ID_ANY, u"Check", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz4.Add(self.Rd2, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		self.Rd3 = wx.RadioButton(self.P2, wx.ID_ANY, u"Radio", wx.DefaultPosition, wx.DefaultSize, 0)
		Hsz4.Add(self.Rd3, 0, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 5)

		Vsz3.Add(Hsz4, 0, wx.ALIGN_CENTER_HORIZONTAL, 5)

		# Hsz7 = wx.BoxSizer( wx.HORIZONTAL )
		#
		# self.chk1 = wx.CheckBox( self.P2, wx.ID_ANY, _(u"Disable"), wx.DefaultPosition, wx.DefaultSize, 0 )
		# Hsz7.Add( self.chk1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
		#
		# self.chk2 = wx.CheckBox( self.P2, wx.ID_ANY, _(u"Hide"), wx.DefaultPosition, wx.DefaultSize, 0 )
		# Hsz7.Add( self.chk2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )
		#
		#
		# Vsz3.Add( Hsz7, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		self.lin1 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.lin1, 0, wx.EXPAND |wx.ALL, 5 )

		Hsz8 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl8 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Program:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl8.Wrap( -1 )

		Hsz8.Add( self.lbl8, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.probtn = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		self.probtn.SetToolTip( _(u"list of program can changed" ) )

		Hsz8.Add( self.probtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz8, 1, wx.EXPAND, 5 )

		Vsz4 = wx.BoxSizer( wx.VERTICAL )

		self.prgfld = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz4.Add( self.prgfld, 0, wx.ALL|wx.EXPAND, 5 )

		self.lbl9 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Directory:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl9.Wrap( -1 )

		Vsz4.Add( self.lbl9, 0, wx.ALL, 5 )


		Vsz3.Add( Vsz4, 1, wx.EXPAND, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )

		self.fillitem()


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		#self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_ACTIVATED, self.slctmnu, id = wx.ID_ANY )
		self.TTC1.Bind(dv.EVT_DATAVIEW_SELECTION_CHANGED, self.actitm)
		self.btn1.Bind( wx.EVT_BUTTON, self.addit )
		self.btn2.Bind( wx.EVT_BUTTON, self.edtit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.adlin )
		self.btn5.Bind( wx.EVT_BUTTON, self.updat )
		self.btn6.Bind( wx.EVT_BUTTON, self.info )
		self.btn7.Bind(wx.EVT_BUTTON, self.aplit)
		self.grup.Bind(wx.EVT_SPINCTRL, self.chggrp)
		self.codgnr.Bind( wx.EVT_BUTTON, self.gnrcod )
		self.IcnFile1.Bind( wx.EVT_FILEPICKER_CHANGED, self.chgicn )
		self.Rd1.Bind( wx.EVT_RADIOBUTTON, self.slctyp )
		self.Rd2.Bind( wx.EVT_RADIOBUTTON, self.slctyp )
		self.Rd3.Bind( wx.EVT_RADIOBUTTON, self.slctyp )
		#self.chk1.Bind( wx.EVT_CHECKBOX, self.disbl )
		#self.chk2.Bind( wx.EVT_CHECKBOX, self.hidit )
		self.probtn.Bind( wx.EVT_BUTTON, self.prglst )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def fillitem(self):
		isz = (16, 16)
		il = wx.ImageList(isz[0], isz[1])
		fldridx = il.Add(wx.ArtProvider.GetBitmap(wx.ART_FOLDER, wx.ART_OTHER, isz))
		fldropenidx = il.Add(wx.ArtProvider.GetBitmap(wx.ART_FOLDER_OPEN, wx.ART_OTHER, isz))

		self.TTC1.SetImageList(il)
		self.il = il

		# broot = self.TTC1.AddRoot(u'Toolbar')
		root1 = self.TTC1.GetRootItem()
		broot = self.TTC1.AppendItem(root1, u'Tool Bar')

		self.altol = self.MyMenu.GetAllTB("left join handler on toolbar.handlerid = handler.handlerid \
	                                       left join access on toolbar.acclvlid = access.acclvlid \
										  where access.userid = 1 "
		                                  )
		dictool = self.regrouptoolbar(self.altol)

		for t in dictool:
			gritm = self.TTC1.AppendItem(broot, str(t))
			self.TTC1.SetItemText(gritm, 0, str(t))

			for i in dictool[t]:

				if i[1] == None or i[1] == '':
					#slcticn = il.Add(wx.Bitmap(ICON16_PATH + "separator.png", wx.BITMAP_TYPE_ANY))
					slcticn = il.Add(icon.separator.GetBitmap())
					ditm = self.TTC1.AppendItem(gritm, u'---')
					self.TTC1.SetItemText(ditm, 0, str(i[0]))
					self.TTC1.SetItemText(ditm, 1, u'---')

					self.TTC1.SetItemImage(ditm, fldridx, wx.TreeItemIcon_Normal)  # wx.NO_IMAGE
					self.TTC1.SetItemImage(ditm, slcticn, wx.TreeItemIcon_Selected)

				else:
					ibitmp = wx.Bitmap(ICONS_TOOL + i[2], wx.BITMAP_TYPE_ANY)

					#slcticn = il.Add(wx.Bitmap(ICONS_TOOL + i[2], wx.BITMAP_TYPE_ANY))
					slcticn = il.Add(self.Scalebitmap(ibitmp))
					bitm = self.TTC1.AppendItem(gritm, i[1])
					self.TTC1.SetItemText(bitm, 0, str(i[0]))
					self.TTC1.SetItemText(bitm, 1, i[1])

					self.TTC1.SetItemImage(bitm, fldridx, wx.TreeItemIcon_Normal)  # wx.NO_IMAGE
					self.TTC1.SetItemImage(bitm, slcticn, wx.TreeItemIcon_Selected)

	def Scalebitmap(self, mybitmap):
		myimage = mybitmap.ConvertToImage()
		return myimage.Scale(16,16).ConvertToBitmap()

	def regrouptoolbar(self, tooldata):
		result = {}

		for item in tooldata:
			if item[0] // 100 not in result:
				newitm = [(item[0], item[1], item[2], item[3], item[8])]
				result[item[0] // 100] = newitm
			else:
				result[item[0] // 100].append((item[0], item[1], item[2], item[3], item[8]))
		# print(result)
		return result

	def actitm(self, event):
		#self.slctitm = event.GetEventObject().GetItemText(event.GetItem())
		ps = self.TTC1.GetSelections()
		if len(ps) > 0:

			for itm in self.altol:
				if not self.TTC1.GetItemText(ps[0], 0).isdigit():
					pass
				elif int(self.TTC1.GetItemText(ps[0], 0)) == itm[0]:

					self.mydata = itm
					if itm[1] == None:
						data = [itm[0], u'-----', u'separator', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'',u'', u'FFFF', 1]
						self.setfield(data)
						self.IcnFile1.SetPath(u'')
						self.btmp1.SetBitmap(wx.NullBitmap)
						self.Allinactive(1)
					else:
						#print(self.mydata)
						self.Allinactive(0)
						self.setfield(self.mydata)
				elif int(self.TTC1.GetItemText(ps[0], 0)) < 9:
					#data = [int(self.TTC1.GetItemText(ps[0], 0))*100,u'',u'image.png', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'', u'',u'', u'FFFF', 1]
					#self.setfield(data)
					self.Allinactive(0)
					self.grup.SetValue(int(self.TTC1.GetItemText(ps[0], 0)))
					self.fld1.SetValue('')
					self.fld2.SetValue('')
					self.fld3.SetValue('')
					self.IcnFile1.SetPath('')
					self.btmp1.SetBitmap(wx.NullBitmap)
					self.fld4.SetValue('')
					self.fld6.SetValue('')
		pass

	def setfield(self, Data):
		self.grup.SetValue(Data[0]//100)
		self.fld1.SetValue(str(Data[0]))
		self.fld2.SetValue(Data[6])
		self.fld3.SetValue(Data[1])
		self.IcnFile1.SetPath(ICONS_TOOL+Data[2])
		if Data[2] == u'separator' or Data[2] == None:
			self.btmp1.SetBitmap(icon.separator.GetBitmap())
		elif Data[2] == u'image.png':
			self.btmp1.SetBitmap(icon.image.GetBitmap())
		else:
			self.btmp1.SetBitmap(wx.Bitmap(self.IcnFile1.GetPath(), wx.BITMAP_TYPE_ANY))
		#self.btmp1.SetBitmap(wx.Bitmap(self.IcnFile1.GetPath(), wx.BITMAP_TYPE_ANY))
		self.fld4.SetValue(Data[3])
		self.fld6.SetValue(Data[4])

		if Data[7] == 'N':
			self.Rd1.SetValue(1)
		elif Data[7] == 'C':
			self.Rd2.SetValue(1)
		elif Data[7] == 'R':
			self.Rd3.SetValue(1)
		#else:
			#print(Data[7])
		# Radio Button Here
		# if Data[16] != 'FFFF':
		# 	self.chk2.SetValue(1)
		# if Data[17] != 1:
		# 	self.chk1.SetValue(1)

		self.prgfld.SetValue(Data[9]+'.py')
		self.lbl9.SetLabel(_("Directory :")+Src_prg)

	def getfield(self):
		D0 = self.grup.GetValue()
		D1 = self.fld1.GetValue()
		D2 = self.fld2.GetValue()
		D3 = self.fld3.GetValue()
		D4 = self.IcnFile1.GetPath()
		#DR = 1 Radio Select
		D5 = self.fld4.GetValue()
		D6 = self.fld6.GetValue()
		D7 = 0 #self.chk1.GetValue()
		D8 = 0 #self.chk2.GetValue()
		D9 = self.prgfld.GetValue()
		return D0,D1,D2,D3,D4,D5,D6,D7,D8,D9

	def Allinactive(self,do):
		if do:
			self.grup.Disable()
			self.fld1.Disable()
			self.fld2.Disable()
			self.fld3.Disable()
			self.IcnFile1.Disable()
			self.fld4.Disable()
			self.fld6.Disable()
			self.Rd1.Disable()
			self.Rd2.Disable()
			self.Rd3.Disable()
			#self.chk1.Disable()
			#self.chk2.Disable()
			self.prgfld.Disable()
		else:
			self.grup.Enable()
			self.fld1.Enable()
			self.fld2.Enable()
			self.fld3.Enable()
			self.IcnFile1.Enable()
			self.fld4.Enable()
			self.fld6.Enable()
			self.Rd1.Enable()
			self.Rd2.Enable()
			self.Rd3.Enable()
			#self.chk1.Enable()
			#self.chk2.Enable()
			self.prgfld.Enable()

	def rclkitm(self, event):
		event.Skip()

	def slctmnu( self, event ):
		event.Skip()

	def addit( self, event ):
		grp = self.grup.GetValue()
		# print(grp)
		data = [grp * 100, u'', u'image.png', u'', u'', u'', u'', u'N', u'', u'', u'', u'', u'', u'', u'', u'', u'FFFF', 1]

		self.setfield(data)
		self.fld1.SetValue(u'')
		event.Skip()

	def edtit( self, event ):
		thsdata = self.getfield()

		if int(thsdata[1]) // 100 != int(thsdata[0]):
			wx.MessageBox(
				_('Please press Add button and then press [...] generator cod button. Group and cod NOT match'))
			return 1
		else:
			icn = thsdata[4].split("\\")[-1]
			hnd = thsdata[9].replace('.py', '')
			# if hnd == '':
			#	hndlrid = 99000
			# else:
			hndlrid = self.findhandler(hnd)
			#	hndlrid = 10001

			if thsdata[7]:
				disen = 0
			else:
				disen = 1
			if thsdata[8]:
				shwid = '0000'
			else:
				shwid = 'FFFF'
			Data1 = [thsdata[3], icn, thsdata[5], thsdata[6], hndlrid, thsdata[2], self.Ttype]
			self.DoMenu.Table = u"toolbar"
			self.DoMenu.Upditem(u'toolname = ? , toolicon = ? , shrttxt = ? , lngtxt = ? , \
					                handlerid = ? , acclvlid = ?, tooltype = ? where  toolid = %d ' % int(thsdata[1]), Data1)

			Data2 = [1, shwid, disen]
			self.DoMenu.Table = u'access'
			self.DoMenu.Upditem(u'userid = ? , acclvl = ?, disenable = ? where acclvlid = "%s" ' % thsdata[1], Data2)

			wx.MessageBox(_(u"successful change Toolbar in program"))

			self.EdtTool(thsdata, icn)

			self.TTC1.DeleteAllItems()
			self.fillitem()
			self.Refresh()
		event.Skip()

	def delit( self, event ):
		thsdata = self.getfield()
		# print(thsdata)

		self.DoMenu.Table = u"toolbar"
		self.DoMenu.Delitem(u"toolbar.toolid = %d " % int(thsdata[1]))
		self.DoMenu.Table = u"access"
		self.DoMenu.Delitem(u'access.acclvlid = "%s" ' % thsdata[2])
		self.DelTool(thsdata)
		wx.MessageBox(_(u"successful delete Toolbar at program"))

		self.TTC1.DeleteAllItems()
		self.fillitem()
		self.Refresh()
		event.Skip()


	def adlin( self, event ):
		d = self.grup.GetValue()

		lstcod = self.MyMenu.GetAllTB(" Where toolbar.toolid/100 = %d" % d)
		if len(lstcod) <= 1:
			wx.MessageBox(_(u"Please First Add 1 item then use line separator"))
		else:
			icod = lstcod[-1][0] + 1
			iData1 = [icod]
			self.DoMenu.Table = u"toolbar"
			self.DoMenu.Additem(u'toolid ', iData1)
			self.config = wx.GetApp().GetConfig()
			TBP = self.config.Read('Toolbar')
			mw = self.FindWindowByName('main')
			if TBP == '1':
				tb = mw.GetToolBar()
				#tb.AddSeparator()
				tb.InsertSeparator(self.GetToolPos(tb,icod))
				tb.Realize()
			elif TBP == '2':
				tb = mw.tool[d - 1]
				tb.AddSeparator()
				tb.Realize()
			else:
				print('we have error in option')

		self.TTC1.DeleteAllItems()
		self.fillitem()
		self.Refresh()
		event.Skip()

	def updat( self, event ):
		self.TTC1.DeleteAllItems()
		self.fillitem()
		self.Refresh()

		mw = self.FindWindowByName('main')

		mw.Refresh()
		mw.Layout()
		event.Skip()

	def info( self, event ):
		print(self.mydata)
		event.Skip()

	def aplit(self, event ):
		ThsData = self.getfield()
		#print(ThsData)
		if ThsData[4].split('\\')[-1] == 'image.png' or ThsData[4] == '':
			wx.MessageBox(_("You must choose an image for tool, Please select a correct image."))
			return 1
		if ThsData[3] == '' or ThsData[2] == '' or ThsData[1] == '':
			wx.MessageBox(_("Please fill the name ,id  and access field, this fields must could not be empty."))
			return 1
		GrpTl = self.MyMenu.GetAllTB(" Where toolid/100 = %d "% int(ThsData[0]) )
		if GrpTl == []:
			GrpTl = [(self.grup.GetValue()*100,'')]
			#print(GrpTl[-1][0])
		if GrpTl[-1][0] != int(ThsData[1]):

			if int(ThsData[1])//100 != int(ThsData[0]):
				wx.MessageBox(_('Please press Add button and then press [...] generator cod button. Group and cod NOT match'))
				return 1
			else:
				icn = ThsData[4].split('\\')[-1]
				#print(icn)
				#self.chkicnpath(ThsData[4])
				hnd = ThsData[9].replace('.py', '')
				hndlrid = self.findhandler(hnd)
				if hndlrid == -1:
					self.prgdir = self.DemoGenerate()
					print(ThsData,(int(ThsData[1])//10)*100)
					hndlrid = 10000+(int(ThsData[1])//10)*100
					iData3 = [hndlrid,'Demo',self.prgdir,'-1',-1,(int(ThsData[1])//10)*100]
					self.DoMenu.Table = u"handler"
					self.DoMenu.Additem(u"handlerid, prgname, prgdir, paramtr, public, prgno",iData3)

				iData1 = [ThsData[1],ThsData[3],icn,ThsData[5],ThsData[6],hndlrid,ThsData[2],self.Ttype]
				self.DoMenu.Table = u"toolbar"
				self.DoMenu.Additem(u'toolid, toolname, toolicon, shrttxt, lngtxt, handlerid, acclvlid, tooltype', iData1)
				if ThsData[7]:
					disen = 0
				else:
					disen = 1
				if ThsData[8]:
					shwid = '0000'
				else:
					shwid = 'FFFF'
				iData2 = [ThsData[2],1,shwid,disen]
				self.DoMenu.Table = u"access"
				self.DoMenu.Additem(u'acclvlid, userid, acclvl, disenable', iData2)

				#print(ThsData[9].replace('.py', ''))
				self.AddTool(ThsData,iData1)
				wx.MessageBox(_(u"successful add Toolbar to program"))

				self.TTC1.DeleteAllItems()
				self.fillitem()
				self.Refresh()

				#iData3 = []
				#self.DoMenu.Table = u"handler"
				#self.DoMenu.Additem(u"handlerid, prgname, prgdir, paramtr, public, prgno",iData3)
		event.Skip()

	def chggrp(self, event):
		grp = self.grup.GetValue()
		if self.fld1.GetValue() != '':
			if int(self.fld1.GetValue())/100 != grp:
				wx.MessageBox(_('Please press Add button and then press [...] generator cod button. Group and cod NOT match'))
				self.grup.SetValue(int(self.fld1.GetValue())/100)

	def gnrcod( self, event ):
		d = self.grup.GetValue()
		lstcod = self.MyMenu.GetAllTB(" Where toolbar.toolid/100 = %d " % d)
		if lstcod == []:
			tbid = (d * 100) + 1
			cd = 'tb'
			accid = str(tbid)[0] + str(tbid)[-1] + cd
		else:
			tbid = lstcod[-1][0] + 1
			cd = lstcod[0][1][0].lower() + lstcod[0][1][-1].lower()
			accid = str(tbid)[0] + str(tbid)[-1] + cd

		if self.fld1.GetValue() == '':
			self.fld1.SetValue(str(tbid))

		if self.fld2.GetValue() == '':
			self.fld2.SetValue(accid)
		event.Skip()

	def chgicn( self, event ):
		if ICONS_TOOL[1:] not in self.IcnFile1.GetPath():
			#print(self.IcnFile1.GetPath(),ICONS_TOOL)
			CopyIcon(self.IcnFile1.GetPath(),'Toolbar')
		self.btmp1.SetBitmap(wx.Bitmap(self.IcnFile1.GetPath(), wx.BITMAP_TYPE_ANY))
		event.Skip()

	def slctyp( self, event ):
		if self.Rd1.GetValue():
			self.Ttype = 'N'
		elif self.Rd2.GetValue():
			self.Ttype = 'C'
		elif self.Rd3.GetValue():
			self.Ttype = 'R'
		else:
			self.Ttype = 'S'

		event.Skip()

	# def disbl( self, event ):
	# 	event.Skip()
	#
	# def hidit( self, event ):
	# 	event.Skip()

	def findhandler(self, hndlrnm):
		if hndlrnm == '':
			if len(self.MyMenu.getHndlr("Demo")) > 0:
				codid, self.prgdir = self.MyMenu.getHndlr("Demo")[0]
			else:
				codid = -1
			return codid
		else:
			codid , self.prgdir = self.MyMenu.getHndlr(hndlrnm)[0]
			return codid

	def finddir(self, data):
		# print(data)
		aldir = self.MyMenu.AllGuiDir()
		for dr in aldir:
			if data in dr:
				# print(dr)
				return dr[1]
		return ''

	def DemoGenerate(self):
		if self.finddir(Src_prg) != '':
			dircod = self.finddir(Src_prg)
			return dircod
		else:
			#dircod = '1' + self.fld1.GetValue()  # +'1'
			dircod = '1' + '0' + str(self.grup.GetValue()) + '1'
			self.iSrc_prg = self.MyMenu.GetImpCod('1000')[0][0]
			self.iSrc_dir = self.MyMenu.GetDirCod('1000')[0][0]
			mydir = Src_prg+'TB'

			self.DoMenu.Table = u'Guidir'
			self.DoMenu.Additem(u' Dir, prgdir, hdddir', ( mydir.replace(Src_prg,self.iSrc_prg) , dircod, self.iSrc_dir+'TB'))
			if not os.path.isdir(mydir):
				os.mkdir(mydir)
			os.chdir(mydir)
			# print(mydir)
			if not os.path.isfile(mydir + SLASH + u'__init__.py'):
				with open(u'__init__.py', u'w+') as f:
					f.write('')
			# print(mydir)
			GenrDemo(mydir)
			if not os.path.isfile(Src_gui + u"SamPnl.py"):
				shutil.copy(GUI_PATH + 'API' + SLASH + 'SamPnl.py', Src_gui)
			return dircod

	def prglst( self, event ):
		if wx.FindWindowByName(u'Program Develop') == None:
			#print(self.mydata)
			if self.prgfld.GetValue() != '' and self.prgfld.GetValue() != '.py':
				import DCC1.ProgDev2 as DP
				ifrm = wx.Frame(self, -1, style=wx.FRAME_FLOAT_ON_PARENT | wx.DEFAULT_FRAME_STYLE)
				pnl = DP.MyPanel1(ifrm,[self.GetParent(),self.prgfld.GetValue().replace('.py',''),self.mydata[5]])
				ifrm.SetSize((555, 500))
				ifrm.SetTitle(u'Program Develop')
				ifrm.Show()
				#print( ifrm.TransferDataFromWindow() )

		else:
			wx.MessageBox(_("Double Program: Please Close Program Develop then Do this item"))
		event.Skip()

	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255 )
		self.Splt1.Unbind( wx.EVT_IDLE )

	def AddTool(self, D, iD):
			self.config = wx.GetApp().GetConfig()
			TBP = self.config.Read('Toolbar')
			if TBP == '1':
				mw = self.FindWindowByName('main')
				tb = mw.GetToolBar()
				ppos = self.GetToolPos(tb,int(D[1])-1)
				#ppos = tb.GetToolPos(int(D[1]) - 1)
				#print(ppos,tb.GetToolPos(int(D[1]) - 1))
				TTT = self.GetToolType()
				if ppos != -1:
					tb.InsertTool(ppos + 1, int(D[1]), str(D[3]), wx.Bitmap(ICONS_TOOL + iD[2]), wx.NullBitmap,
					              TTT, str(D[5]),
					              str(D[6]))
				else:
					tb.AddTool(int(D[1]), str(D[3]), wx.Bitmap(ICONS_TOOL + iD[2]), wx.NullBitmap, TTT,
					           str(D[5]), str(D[6]))
				tb.Realize()
			elif TBP == '2':
				mw = self.FindWindowByName('main')
				# print(D, iD, len(mw.tool))
				if len(mw.tool) < D[0]:
					MTB = MyAuiToolbar(mw)
					MyTL = [iD]
					mw.tool.append(MTB.CreatTool(MyTL))

					mw.tool[-1].SetToolBitmapSize(wx.Size(24, 24))
					mw.tool[-1].Realize()
					mw.m_mgr.AddPane(mw.tool[-1], wx.aui.AuiPaneInfo().Name("tb" + str(D[0])).Caption("Toolbar").
					                 ToolbarPane().Top().LeftDockable(True).RightDockable(False))
				# MyAuiToolbar.CreatTool(tbData)
				else:
					tb = mw.tool[D[0] - 1]
					# print(tb)
					# ppos  = tb.FindTool(int(D[1])-1)
					# print(ppos)
					TTT = self.GetToolType()
					tb.AddTool(int(D[1]), str(D[3]), wx.Bitmap(ICONS_TOOL + iD[2]), wx.NullBitmap, TTT,
					           str(D[5]), str(D[6]), None)
					tb.Realize()

			else:
				print('some wrong')

	def EdtTool(self, D, icn):
			self.config = wx.GetApp().GetConfig()
			TBP = self.config.Read('Toolbar')
			mw = self.FindWindowByName('main')
			if TBP == '1':
				tb = mw.GetToolBar()
				# ppos = tb.GetToolPos(int(D[1]) - 1)
				ttb = tb.FindById(int(D[1]))
				ttb.SetLabel(D[3])
				tb.SetToolNormalBitmap(int(D[1]), wx.Bitmap(ICONS_TOOL + icn))
				tb.SetToolShortHelp(int(D[1]), str(D[5]))
				tb.SetToolLongHelp(int(D[1]), str(D[6]))

			elif TBP == '2':
				if len(mw.tool) == 0:
					wx.MessageBox(_(u'Please select toolbar or create it'))
				else:
					tb = mw.tool[D[0] - 1]
					tb.SetToolLabel(int(D[1]), D[3])
					tb.SetToolBitmap(int(D[1]), wx.Bitmap(ICONS_TOOL + icn))
					tb.SetToolShortHelp(int(D[1]), str(D[5]))
					tb.SetToolLongHelp(int(D[1]), str(D[6]))

	def DelTool(self, D):
			self.config = wx.GetApp().GetConfig()
			TBP = self.config.Read('Toolbar')
			# print(TBP)
			mw = self.FindWindowByName('main')
			if TBP == '1':
				# print(mw)
				tb = mw.GetToolBar()
				thstool = tb.FindById(int(D[1]))
				#print(thstool)
				#tb.DeleteTool(int(D[1]))
				if thstool != None:
					thstool.GetToolBar().DeleteTool(int(D[1]))
				else:
					tb.RemoveTool(int(D[1]))

			else:
				tb = mw.tool[D[0] - 1]
				# print(tb)
				itb = tb.FindTool(int(D[1]))
				tb.DeleteTool(int(D[1]))
			tb.Realize()

	def GetToolType(self):
		if self.Ttype == 'N':
			return wx.ITEM_NORMAL
		elif self.Ttype == 'C':
			return wx.ITEM_CHECK
		elif self.Ttype == 'R':
			return wx.ITEM_RADIO
		else:
			return wx.ITEM_SEPARATOR

	def GetToolPos(self,tb,id):
		lstid = 101
		for i in range(tb.GetToolsCount()):
			tpos = tb.GetToolByPos(i)
			if tpos.IsButton():
				lstid = tpos.GetId()
				if lstid == id:
					return i
			if tpos.IsSeparator():
				if lstid//100 == id//100:
					return i
		return -1

